/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.DateiTransfer
 *
 * de.bsvrz.kex.tls.osi7.conversion.DateiTransfer is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.DateiTransfer is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.DateiTransfer.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.DateiTransfer.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.DateiTransfer ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.DateiTransfer wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */



package de.bsvrz.kex.tls.osi7.conversion;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.kex.tls.osi7.De;
import de.bsvrz.kex.tls.osi7.DeBlock;
import de.bsvrz.kex.tls.osi7.IllegalOsi7TelegramStructureException;
import de.bsvrz.kex.tls.osi7.TlsData;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.hexdump.HexDumper;

import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Dateitransfer-Methoden zur FG 254
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kniß (HCK)
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class DateiTransfer {

    /** maximale Anzahl Daten pro Block. */
    private static final int DATEITRANSFER_MAX_DATABLOCK_DATA = 223;

    // ------------------------------------------------------------------------
    // VARIABLENDEKLARATIONEN
    // ------------------------------------------------------------------------
    // Sonstige ---------------------------------------------------------------

    /** DebugLogger für Debug-Ausgaben */
    private static final Debug debug = Debug.getLogger();

    //~ FELDER ================================================================

    /** Flag, ob die Datei vollst&auml;ndig empfangen wurde. */
    private boolean dateiKomplett = false;

    /** Letzter versendeter DE-Block des Transfers. */
    private DeBlock lastDeBlockSent = null;

    /** Der aktuell empfangene Block. */
    private int aktuellerBlock;

    /** Die Anzahl der Datenbl&ouml;cke. */
    private int anzahlBloecke;

    /** Bezeichner. */
    private String bezeichner;

    /** Die Daten. */
    private byte[] dateiDaten;

    /** L&auml;nge des Bezeichners. */
    private int laengeBezeichner;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Konstruktor.
     */
    public DateiTransfer() {
        clear();
    }

    //~ METHODEN ==============================================================

    /**
     * F&uuml;gt einen DE-Block zum aktuellen Datentransfer hinzu.
     *
     * @param deBlock De-Block mit empfangenen Daten
     */
    public void addDataBlock(final DeBlock deBlock) {
        aktuellerBlock = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        debug.finest("Blocknummer: " + aktuellerBlock);

        if (aktuellerBlock == 1) {
            clear();
            anzahlBloecke = deBlock.getDeData().readUnsignedLowHighByteAsInt();

            TlsData _TlsData_ = deBlock.getDeData().readNextTlsDataBlock();

            laengeBezeichner = _TlsData_.length();
            bezeichner       = new String(_TlsData_.toBytes());
            debug.finest("Anzahl Datenblöcke: " + anzahlBloecke + ", Länge Bezeichner: " + laengeBezeichner + ", Bezeichner: " + bezeichner);
        } else {
            TlsData _TlsData_   = deBlock.getDeData().readNextTlsDataBlock();
            int     datenLaenge = _TlsData_.length();
            int     alteLaenge  = dateiDaten.length;

            debug.finest("Daten: " + datenLaenge + "Byte(s)");

            byte[] dateiDatenNeu = new byte[alteLaenge + datenLaenge];

            System.arraycopy(dateiDaten, 0, dateiDatenNeu, 0, alteLaenge);
            System.arraycopy(_TlsData_.toBytes(), 0, dateiDatenNeu, alteLaenge, datenLaenge);
            dateiDaten = dateiDatenNeu;
        }

        deBlock.getDeData().rewindReadPosition();
        dateiKomplett = aktuellerBlock == anzahlBloecke;
    }

    /**
     * Setzt den Dateitransfer zur&uuml;ck.
     */
    private void clear() {
        aktuellerBlock  = 0;
        anzahlBloecke   = 0;
        dateiKomplett   = false;
        dateiDaten      = new byte[0];
        lastDeBlockSent = null;
    }

    /**
     * Realisiert den Dateitransfer entsprechend<br>
     * FG 254 : Typ: 41 Id: 3  Name: Dateitransfer (Abruf / Antwort). TLS-Datenbeschreibung:<br>
     * <pre>
     * Erster Block:
     *
     * Position         Bezeichnung                             Erl&auml;uterung
     * Byte 1           L&auml;nge DE-Block                     L&auml;nge des folgenden DE-Blocks
     * Byte 2           Daten-Endger&auml;te-Kanal              [ 0..254 ]
     * Byte 3           Typ der DE-Daten                        [ 41 ]
     * Byte 4           Blocknummer low Byte                    [ 1 ]
     * Byte 5           Blocknummer high Byte
     * Byte 6           Anzahl Datenbl&ouml;cke low Byte        [ 2..65535 ]
     * Byte 7           Anzahl Datenbl&ouml;cke high Byte
     * Byte 8           L&auml;nge Bezeichner                   [ 1..221 ]
     * Byte 9           Bezeichner                              ASCII-Zeichensatz
     * Byte 10                                                  (z.B. "C:\WVZ_231.BMP")
     *
     * Weitere Bl&ouml;cke:
     *
     * Position         Bezeichnung                             Erl&auml;uterung
     * Byte 1           L&auml;nge DE-Block                     L&auml;nge des folgenden DE-Blocks
     * Byte 2           Daten-Endger&auml;te-Kanal              [ 0..254 ]
     * Byte 3           Typ der DE-Daten                        [ 41 ]
     * Byte 4           Blocknummer low Byte                    [ 0,2..65535 ]
     * Byte 5           Blocknummer high Byte
     * Byte 6           L&auml;nge des Datenblocks              [ 0, 1..223 ]
     * Byte 7           Inhalt des Datenblocks                  [ 0..255 ]
     * Byte 8                                                   [ 0..255 ]
     * </pre>
     *
     * @param result Der vom Datenverteiler empfangene Datensatz.
     * @param de DE-Kanal
     *
     * @return Liste von De-Bloecken mit den konvertierten Daten.
     */
    public List<DeBlock> erzeugeDeBloecke(ResultData result, De de) {
        List<DeBlock> deBlocks = null;
        DeBlock       deBlock;

        clear();

        // Umsetzung
        Data   data         = result.getData();  // Datensatz holen
        int    _Laenge_     = data.getUnscaledValue("LängeBezeichner").intValue();
        String _Bezeichner_ = data.getTextValue("Bezeichner").getText();
        byte[] _Daten_      = data.getUnscaledArray("Daten").getByteArray();

        // falls gewünscht, hier Länge bestimmen
        if (_Laenge_ == -1) {
            _Laenge_ = _Bezeichner_.length();

            if (_Laenge_ > 221) {
                debug.error("Länge 'Bezeichner' zu gross: " + _Laenge_ + "(max. 221)");

                return null;
            }
        }

        // 1. Block erzeugen
        TlsData deApplicationData = new TlsData(1);

        deApplicationData.writeIntAsLowHighByte(1);  // Blocknummer 1

        // Anzahl Blöcke berechnen
        // erster Block
        int anzahlBloecke = 1;

        // weitere Blöcke
        anzahlBloecke += _Daten_.length / DATEITRANSFER_MAX_DATABLOCK_DATA;

        if ((_Daten_.length % DATEITRANSFER_MAX_DATABLOCK_DATA) != 0) {
            anzahlBloecke++;
        }

        deApplicationData.writeIntAsLowHighByte(anzahlBloecke);     // Anzahl Datenbloecke
        deApplicationData.writeIntAsByte(_Laenge_);                 // Länge Bezeichener
        deApplicationData.writeByteArray(_Bezeichner_.getBytes());  // Bezeichener

        try {
            deBlock = new DeBlock(deApplicationData, de.getEak().getSm().getOsi7Adress(), de.getFg(), 41, 3, de.getDeChannel());
            debug.finest("TLS-DE-Block: " + HexDumper.toString(deBlock.getTlsDeDataBlock()));
        }
        catch (IllegalOsi7TelegramStructureException e) {
            debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);

            return null;
        }

        deBlocks = new ArrayList<DeBlock>();
        deBlocks.add(deBlock);

        // Datenbloecke erzeugen
        int _RestLange_ = _Daten_.length;

        for (int i = 0; i < (anzahlBloecke - 1); i++) {
            int blockLaenge;

            if (_RestLange_ > DATEITRANSFER_MAX_DATABLOCK_DATA) {
                blockLaenge = DATEITRANSFER_MAX_DATABLOCK_DATA;
            } else {
                blockLaenge = _RestLange_;
            }

            byte[] blockDaten = new byte[blockLaenge];

            System.arraycopy(_Daten_, _Daten_.length - _RestLange_, blockDaten, 0, blockLaenge);

            TlsData deData = new TlsData(blockLaenge + 3);

            deData.writeIntAsLowHighByte(i + 2);
            deData.writeIntAsByte(blockLaenge);
            deData.writeByteArray(blockDaten);

            try {
                deBlock = new DeBlock(deData, de.getEak().getSm().getOsi7Adress(), de.getFg(), 41, 3, de.getDeChannel());
                debug.finest("TLS-DE-Block: " + HexDumper.toString(deBlock.getTlsDeDataBlock()));
            }
            catch (IllegalOsi7TelegramStructureException e) {
                debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);

                return null;
            }

            _RestLange_ -= blockLaenge;
            deBlocks.add(deBlock);
        }

        for (DeBlock blocki : deBlocks) {
            addDataBlock(blocki);
        }

        lastDeBlockSent = deBlocks.get(deBlocks.size() - 1);

        return deBlocks;
    }

    //~ GET METHODEN ==========================================================

    /**
     * Aufbereitung der DAV-Daten aus dem Dateitransfer.
     *
     * @param data Der passende Datensatz f&uuml;r die Ziel Attributgruppe/Aspekt-Kombination.
     */
    public void getResultData(final Data data) {
        data.getUnscaledValue("LängeBezeichner").set(laengeBezeichner);
        data.getTextValue("Bezeichner").setText(bezeichner);
        data.getArray("Daten").setLength(dateiDaten.length);

        for (int i = 0; i < dateiDaten.length; i++) {
            data.getArray("Daten").getUnscaledValue(i).set(dateiDaten[i]);
        }
    }

    //~ METHODEN ==============================================================

    /**
     * @return true, wenn der Dateitransfer komplett ist, sonst false
     */
    public boolean istKomplett() {
        return dateiKomplett;
    }

    /**
     * Testet, ob ein DE-Block die intern gefundene R&uuml;ckmeldung zur positiven
     * Quittung eines Dateitransfers ist. F&uuml;r diese internen R&uuml;ckmeldungen
     * wird jeweils der letzte versendete Block zu einer Jobnummer gespeichert
     * (TlsApplicationLayer). Da alle einzelnen Bl&ouml;cke eines Dateitransfers
     * mit der gleichen Jobnummer versendet werden, wird hier als Parameter der
     * letzte DE-Block des Transfers erwartet.
     *
     * @param deBlock DE-Block
     * @return true wenn der DE-Block (inhaltlich) gleich dem letzten versendeten DE-Block
     * dieses Dateitransfers ist, sonst false
     */
    public boolean istQuittierung(DeBlock deBlock) {
        if (lastDeBlockSent == null) {
            return false;
        }

        // binärer Datenvergleich
        return ByteBuffer.wrap(lastDeBlockSent.getTlsDeDataBlock()).equals(ByteBuffer.wrap(deBlock.getTlsDeDataBlock()));
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 11.09.09
