/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.Fg006Default
 *
 * de.bsvrz.kex.tls.osi7.conversion.Fg006Default is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg006Default is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.Fg006Default.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.Fg006Default.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg006Default ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg006Default wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */

package de.bsvrz.kex.tls.osi7.conversion;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.IntegerValueState;
import de.bsvrz.kex.tls.osi7.*;
import de.bsvrz.sys.funclib.debug.Debug;

import java.util.ArrayList;
import java.util.List;

/**
 * Umsetungsmodul für die FG 6, Standard (alle Typen der FG 6 gemäß TLS 2002). Angemeldet werden aber nur die
 * Telegrammtypen, die bei allen FG 3 DE identisch sind, also DeFehler, Kanalsteuerung etc. Umsetzungsmodul enthält zwar
 * alle Umsetzungsmethoden, für einen konkreten FG 6 Typ (z.B. TemperaturÜberwachung) ist aber für dieses De in der
 * Konfiguration als Umsetzungsklasse die spezielle, von dieser Klasse abgeleitete Klasse (bei TemperaturÜberwachung
 * {@link Fg006Typ048} ) zu verwenden, in der dann die spezifischen Umsetzungsmethoden angemeldet werden. Bei FG 6 De
 * ist Angabe der speziellen Umsetzungsklasse in der Konfiguration obligatorisch, es wird keine Umsetzungklasse bei
 * Fehlen einer solchen Angabe standardmäßig verwendet! Erweiterung: unterstützt auch nachgelieferte Telegramme
 * (Standard ID+32)
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @version $Revision$ / $Date$ / ($Author$)
 */

public class Fg006Default extends FgAllDefault {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Sonstige ---------------------------------------------------------------
	/** DebugLogger für Debug-Ausgaben */
	private static final Debug debug = Debug.getLogger();
// Private ----------------------------------------------------------------
	/**
	 * Tabelle, in der das Verhalten beim Empfang von Attributgruppen eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.parameterSoll", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Empfangsanmeldung als Empfänger.</li> <li> In der Methode {@link #update} wird für jede zur
	 * Attributgruppen/Aspket-Kombination passende Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag
	 * wie folgt gebildet wird (hier für den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll(ResultData)</code><br>
	 * Dabei enthält <code>ResultData</code> die Daten der zu verarbeitenden ATG/ASP-Kombination.</li> <li> Für jede
	 * Attributguppen/Aspekt Kombination erfolgt eine Empfangsanmeldung als Empfänger. Sind mehrere passende Eintrage
	 * vorhanden, werden entsprechend mehrere Methodenaufrufe durchgeführt. Dadurch können mehrere ATG/ASP-Kombinationen in
	 * einen De-Block abgebildet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eines Fachmodells):</li>
	 * <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */
	private final Object[][] davToTls = new Object[][]{
			// Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
			{"atg.tlsGloDeBlockAbruf", "asp.tlsAbruf", "255", "255", "255", "typ.deVlt"},
			{"atg.tlsGloDeBlockSenden", "asp.tlsVorgabe", "255", "255", "255", "typ.deVlt"},
			{"atg.tlsGloKanalSteuerung", "asp.parameterSoll", "255", "29", "2", "typ.deVlt"},
			{"atg.tlsGloGeographischeKenndaten", "asp.tlsVorgabe", "255", "36", "3", "typ.deVlt"},
			{"atg.tlsVltBetriebsParameter", "asp.parameterSoll", "6", "32", "3", "typ.deVlt"}
	};

	/**
	 * Tabelle, in der das Verhalten beim Empfang von TLS De-Blöcken eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.tlsAntwort", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Sendeanmeldung als Quelle.</li> <li> In der Methode {@link #processDeBlock} wird für jede zum De-Block passende
	 * Fg/Id/Typ-Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag wie folgt gebildet wird (hier für
	 * den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspTlsAntwort(DeBlock, Data,
	 * DataDescription)</code><br> Dabei enthält der <code>deBlock</code> die Daten des zu verarbeitenden De-Blocks und
	 * <code>data</code> ein Datenobjekt der passenden Attributgruppen/Aspekt-Kombination, welchem direkt die Inhalte des
	 * De-Blocks zugewiesen werden können.<code>DataDescription</code> enthält die passende {@link
	 * DataDescription} für die zu sendenden Daten.</li> <li> Für jede Attributguppen/Aspekt
	 * Kombination erfolgt eine Sendeanmeldung als Quelle. Sind mehrere passende Eintrage vorhanden, werden entsprechend
	 * mehrere Methodenaufrufe durchgeführt. Dadurch kann ein De-Block mehrfach ausgewert und an verschiedene
	 * Attributgruppen weitergerleitet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eine
	 * Fachmodells):</li> <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */

	private final Object[][] tlsToDav = new Object[][]{
			{"atg.tlsGloDeFehler", "asp.tlsAntwort", "6", "1", "1", "typ.deVlt"},
			{"atg.tlsGloDeFehler", "asp.tlsAntwort", "6", "1", "33", "typ.deVlt"},
			{"atg.tlsGloKanalSteuerung", "asp.parameterIst", "255", "29", "2", "typ.deVlt"},
			{"atg.tlsGloKanalSteuerung", "asp.parameterIst", "255", "29", "34", "typ.deVlt"},
			{"atg.tlsGloGeographischeKenndaten", "asp.tlsZustand", "255", "36", "3", "typ.deVlt"},
			{"atg.tlsGloGeographischeKenndaten", "asp.tlsZustand", "255", "36", "35", "typ.deVlt"},
			{"atg.tlsVltErgänzendeDeFehlerMeldung", "asp.tlsAntwort", "6", "14", "1", "typ.deVlt"},
			{"atg.tlsVltErgänzendeDeFehlerMeldung", "asp.tlsAntwort", "6", "14", "33", "typ.deVlt"},
			{"atg.tlsVltNegativeQuittung", "asp.tlsAntwort", "6", "16", "2", "typ.deVlt"},
			{"atg.tlsVltNegativeQuittung", "asp.tlsAntwort", "6", "16", "34", "typ.deVlt"},
			{"atg.tlsVltBetriebsParameter", "asp.parameterIst", "6", "32", "3", "typ.deVlt"},
			{"atg.tlsVltBetriebsParameter", "asp.parameterIst", "6", "32", "35", "typ.deVlt"}
	};

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt ein Objekt vom Typ Fg001Default
	 *
	 * @param daf DaV
	 * @param eak Eak
	 * @param de De
	 */
	public Fg006Default(ClientDavInterface daf, Eak eak, De de) {
		super(daf, eak, de);
		subscribeAllData(tlsToDav, davToTls);
	}

// ------------------------------------------------------------------------
// SONSTIGE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg006Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(DeBlock,Data,
	 *DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ001Id033AtgTlsGloDeFehlerAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 1, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg006Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 6 : Typ: 1 Id: 1 Name: DE-Fehler (Antwort). Ergänzt globale Behandlung De-Fehler in {@link
	 * #Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort}. Beim Empfang einer De-Gutmeldung wird die De initialisiert, indem
	 * <ul> <li>VLT-kanalsteuerung {@link #Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll}</li>
	 * <li>VLT-betriebsparameter{@link #Fg006Typ032Id003AtgTlsVltBetriebsParameterAspParameterSoll}</li> </ul> versendet
	 * werden.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = super.Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(deBlock, data, dataDescription);

		IntegerValueState DEFehlerStatus = data.getUnscaledValue("DEFehlerStatus").getState();
		if (DEFehlerStatus != null) {
			debug.fine("DEFehlerStatus: " + DEFehlerStatus.getName());
			if (DEFehlerStatus.getName().equals("ok")) {
				sendInitialDeBlock(deBlock.getKey(), 29, 2);// Vlt-Kanalsteuerung senden
				sendInitialDeBlock(deBlock.getKey(), 32, 3);// Vlt-Betriebsparameter senden
			}
			else {
				List deList = new ArrayList();
				deList.add(_de);
				TlsApplicationLayer.writeNoDataToUnreachableDe(deList, _eakConversionModul.getTimeStamp(), -1, "atg.tlsGloDeFehler");
			}
		}
		return resultData;
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg006Typ014Id001AtgTlsVltErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ014Id033AtgTlsVltErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 1, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg006Typ014Id001AtgTlsVltErgänzendeDeFehlerMeldungAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 6 : Typ: 14 Id: 1 Name: Ergänzende DE-Fehlermeldung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          [ 9..29 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 14 ]
	 * Byte 4           Herstellercode                          (s. Anh. 7, Kap. 2)
	 * Byte 5           Anzahl TLS - Fehlerbytes                [ 4 ]
	 * Byte 6           TLS - Fehlerbyte 1                      Codierung siehe unten
	 * Byte 7           TLS - Fehlerbyte 2                      Codierung siehe unten
	 * Byte 8           TLS - Fehlerbyte 3                      Codierung siehe unten
	 * Byte 9           TLS - Fehlerbyte 4                      Codierung siehe unten
	 * Byte 10          Anzahl Hersteller Fehlerbytes           [ 0..20 ]
	 * Byte 11          Hersteller-Fehlerbyte 1                 herstellerspez. Codierung
	 * Byte..           Hersteller-Fehlerbyte n                 herstellerspez. Codierung
	 * </pre>
	 * <br> Inhalt TLS-Fehlerbytes:<br> Die Fehlerbytes sind bitweise codiert. Jedes Bit definiert einen bestimmten Fehler,
	 * wobei das Bit gleich 1 gesetzt ist.<br> Es können auch mehrere Bit gleichzeitig gesetzt werden. Der Inhalt der
	 * Fehlerbytes ist optional. D.h. bei einer Realisierung dieses Telegrammtyps müssen vom Hersteller nicht alle in der
	 * Tabelle definierten Fehlercodes erfüllt werden. Für spätere Definitionen reservierte Bits bzw. nicht verwendete Bits
	 * sind gleich Null zu setzen.<br>
	 * <pre>
	 *         Bit 7      Bit 6       Bit 5       Bit 4          Bit 3         Bit 2       Bit 1       Bit 0
	 * Byte 1  Reserve    Reserve     RNR am      Lokalbus       Reserve       Reserve     Reserve     Teilstörung
	 *                                Lokalbus1   ausgefallen
	 * Byte 2  Reserve    Reserve     Reserve     Reserve        Reserve       Sensor      RNR am      Subbus
	 *                                                                         ausgefallen Subbus      ausgefallen
	 * Byte 3  Reserve    Reserve     Reserve     Reserve        Reserve       Reserve     Reserve     Reserve
	 * Byte 4  Reserve    Reserve     Reserve     Reserve        Reserve       Reserve     Reserve     Reserve
	 * 1) nur in Verbindung mit Stö/SM=1 im Byte 4 der DE-Block-Struktur im Typ 1
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ014Id001AtgTlsVltErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Herstellercode-Byte aus Telegramm ---------------------------------------------------------------------------
		int _Herstellercode_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("Hersteller").set(_Herstellercode_);

		// Fehler-Bytes aus Telegramm -----------------------------------------------------------------------------------
		deBlock.getDeData().readUnsignedByteAsInt();// Anzahl der folgenden Bytes überlesen, da immer == 4 !
		int _TlsFehler1_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler2_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler3_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler4_ = deBlock.getDeData().readUnsignedByteAsInt();

		Data.NumberArray _TlsFehler_ = data.getItem("FehlercodesTLS").getUnscaledArray("Fehler");
		_TlsFehler_.setLength(4);
		_TlsFehler_.getValue(0).set(_TlsFehler1_);
		_TlsFehler_.getValue(1).set(_TlsFehler2_);
		_TlsFehler_.getValue(2).set(_TlsFehler3_);
		_TlsFehler_.getValue(3).set(_TlsFehler4_);

		// Hersteller Fehler-Bytes aus Telegramm -----------------------------------------------------------------------
		int count = deBlock.getDeData().readUnsignedByteAsInt();
		int[] _HerstellerFehler_ = new int[count];
		for (int i = 0; i < count; i++) {
			_HerstellerFehler_[i] = deBlock.getDeData().readUnsignedByteAsInt();
		}

		Data.NumberArray _Fehler_ = data.getItem("FehlercodesHersteller").getUnscaledArray("Fehler");
		_Fehler_.setLength(count);
		for (int i = 0; i < count; i++) {
			_Fehler_.getValue(i).set(_HerstellerFehler_[i]);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg006Typ016Id002AtgTlsVltNegativeQuittungAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ016Id034AtgTlsVltNegativeQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 2, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg006Typ016Id002AtgTlsVltNegativeQuittungAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 6 : Typ: 16 Id: 2 Name: Negative Quittung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 4 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 16 ]
	 * Byte 4           Fehlerursache                           siehe unten
	 * Byte 5           Herstellercode                          siehe Liste in Anhang 7, Kap. 2
	 * </pre>
	 * Inhalt Byte: Fehlerursache unter FG 6:<br>
	 * <pre>
	 *        0:   sonstige Fehlerursache
	 *        1:   unbekannte oder nicht auswertbare ID
	 *        2:   unbekannter oder nicht auswertbarer Typ
	 *   3..127:   reserviert für spätere Definitionen
	 * 128..255:   frei für herstellerdefinierte Ursachencodes
	 *
	 * </pre>
	 * Inhalt Byte Herstellercode<br> Der Herstellercode ist ein für jeden Hersteller eindeutig zugeordneter Code, der der
	 * Zentrale die Zuordnung der Nachrichten erleichtern soll.<br>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ016Id002AtgTlsVltNegativeQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		return super.Fg255Typ016Id002AtgTlsGloNegativeQuittungAspTlsAntwort(deBlock, data, dataDescription);
	}

	/**
	 * FG 6 : Typ: 32 Id: 3 Name: Betriebsparameter (Abruf / Antwort).
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 5 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254, 255 ,(evt. Clusterkanal)1 ]
	 * Byte 3           Typ der DE-Daten                        [ 32 ]
	 * Byte 4           Erfassungsperiodendauer                 [ 0..65535 s ] low Byte
	 * Byte 5           Erfassungsperiodendauer                 high Byte
	 * Byte 6           Übertragungsverfahren                   siehe unten
	 * 1) im Anwendungsfall Clusterkanal gilt entsprechend die Definition Seite A6, Teil 2, Kapitel 6.2.7
	 * </pre>
	 * Inhalt Byte Übertragungsverfahren<br> Das Byte gibt Anweisung, wann die Daten der Messwertgeber zur Zentrale
	 * übertragen werden: Entweder auf Abruf durch die Zentrale (Ereignisklasse 2), oder nach Zustandsänderungen
	 * (Ereignisklasse 1).Optional können die Daten auch spontan nach Ende der o.g. Erfassungsperiode (Ereignisklasse 1)
	 * übertragen werden. Meldung nur nach Abruf durch die Zentrale bedeutet, dass der DE ohne Aufforderung keine Meldungen
	 * mehr abgibt.<br> Das Standardübertragungsverfahren in der FG 6 ist die spontane Meldung nach
	 * Zustandsänderungen.<br>
	 * <pre>
	 *          0:  Meldung nur nach Abruf
	 *          1:  zyklische Abgabe von Meldungen (optional)
	 *          2:  nach Zustandsänderung
	 *     3..255:  nicht definiert
	 * </pre>
	 * Der Wert "Erfassungsperiodendauer" gibt an, in welchen zeitlichen Abständen die Übertragung der Betriebsmeldungen
	 * erfolgen soll.<br> Der Wert "Erfassungsperiodendauer" ist nur relevant bei der zyklischen Abgabe von Meldungen (Byte
	 * "Übertragungsverfahren" = 1).<br>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg006Typ032Id003AtgTlsVltBetriebsParameterAspParameterSoll(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _Erfassungsperiodendauer_;
		int _Übertragungsverfahren_;

		// Umsetzung
		Data data = result.getData();// Datensatz holen

		_Erfassungsperiodendauer_ = data.getUnscaledValue("Erfassungsperiodendauer").intValue();
		_Übertragungsverfahren_ = data.getUnscaledValue("Übertragungsverfahren").intValue();

		// DeBlock als TlsData aufbauen...

		TlsData deApplicationData = new TlsData(3);
		deApplicationData.writeIntAsLowHighByte(_Erfassungsperiodendauer_);
		deApplicationData.writeIntAsByte(_Übertragungsverfahren_);

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 32, 3, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg006Typ032Id003AtgTlsVltBetriebsParameterAspParameterIst(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ032Id035AtgTlsVltBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg006Typ032Id003AtgTlsVltBetriebsParameterAspParameterIst(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 6 : Typ: 32 Id: 3 Name: Betriebsparameter (Abruf / Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 5 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254, 255 ,(evt. Clusterkanal)1 ]
	 * Byte 3           Typ der DE-Daten                        [ 32 ]
	 * Byte 4           Erfassungsperiodendauer                 [ 0..65535 s ] low Byte
	 * Byte 5           Erfassungsperiodendauer                 high Byte
	 * Byte 6           Übertragungsverfahren                   siehe unten
	 * 1) im Anwendungsfall Clusterkanal gilt entsprechend die Definition Seite A6, Teil 2, Kapitel 6.2.7
	 * </pre>
	 * Inhalt Byte Übertragungsverfahren<br> Das Byte gibt Anweisung, wann die Daten der Messwertgeber zur Zentrale
	 * übertragen werden: Entweder auf Abruf durch die Zentrale (Ereignisklasse 2), oder nach Zustandsänderungen
	 * (Ereignisklasse 1).Optional können die Daten auch spontan nach Ende der o.g. Erfassungsperiode (Ereignisklasse 1)
	 * übertragen werden. Meldung nur nach Abruf durch die Zentrale bedeutet, dass der DE ohne Aufforderung keine Meldungen
	 * mehr abgibt.<br> Das Standardübertragungsverfahren in der FG 6 ist die spontane Meldung nach
	 * Zustandsänderungen.<br>
	 * <pre>
	 *          0:  Meldung nur nach Abruf
	 *          1:  zyklische Abgabe von Meldungen (optional)
	 *          2:  nach Zustandsänderung
	 *     3..255:  nicht definiert
	 * </pre>
	 * Der Wert "Erfassungsperiodendauer" gibt an, in welchen zeitlichen Abständen die Übertragung der Betriebsmeldungen
	 * erfolgen soll.<br> Der Wert "Erfassungsperiodendauer" ist nur relevant bei der zyklischen Abgabe von Meldungen (Byte
	 * "Übertragungsverfahren" = 1).<br>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ032Id003AtgTlsVltBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Erfassungsperiodendauer-Byte aus Telegramm ------------------------------------------------------------------
		int _Erfassungsperiodendauer_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("Erfassungsperiodendauer").set(_Erfassungsperiodendauer_);

		// Erfassungsperiodendauer-Byte aus Telegramm ------------------------------------------------------------------
		int _Übertragungsverfahren_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("Übertragungsverfahren").set(_Übertragungsverfahren_);

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 48 Id: 4  Name: Türkontakt (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Tür geschlossen               Tür offen
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ048Id004AtgTlsVltTürKontaktAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
				data.getUnscaledValue("Türkontakt").set((_Zustand_ & 0x01));
				break;
			default:
				debug.warning("Türkontakt-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 49 Id: 4  Name: Temperaturüberwachung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Überwachung ok                Überwachung defekt
	 * 1                       Bereich nicht überschritten   Bereich überschritten
	 * 2                       Bereich nicht unterschritten  Bereich unterschritten
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ049Id004AtgTlsVltTemperaturÜberwachungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
			case 2:
			case 3:
			case 4:
			case 5:
				data.getUnscaledValue("TemperaturÜberwachung").set(_Zustand_ & 0x01);
				data.getUnscaledValue("TemperaturBereichObereGrenze").set((_Zustand_ & 0x02) >>> 1);
				data.getUnscaledValue("TemperaturBereichUntereGrenze").set((_Zustand_ & 0x04) >>> 2);
				break;
			default:
				debug.warning("TemperaturÜberwachung-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 50 Id: 4  Name: Licht (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * </pre>
	 * Typ 50: Licht<br>
	 * <pre>
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       ausgeschaltet                 eingeschaltet
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ050Id004AtgTlsVltLichtAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
				data.getUnscaledValue("Licht").set((_Zustand_ & 0x01));
				break;
			default:
				debug.warning("Licht-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 51 Id: 4  Name: Stromversorgung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Netzspannung ok               Netzspannung ausgefallen
	 * 1                       USV ok                        USV defekt
	 * 2                       Akku nicht entladen           Akku entladen
	 * 3                       Akku nicht überladen          Akku überladen
	 * 4                       FI-Schutzschalter             FI-Schutzschalter
	 *                         eingeschaltet                 ausgelöst
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ051Id004AtgTlsVltStromVersorungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		if (_Zustand_ < 32) {
			data.getUnscaledValue("Netzspannung").set(_Zustand_ & 0x01);
			data.getUnscaledValue("USV").set((_Zustand_ & 0x02) >>> 1);
			data.getUnscaledValue("Akkuentladung").set((_Zustand_ & 0x04) >>> 2);
			data.getUnscaledValue("Akkuüberladung").set((_Zustand_ & 0x08) >>> 3);
			data.getUnscaledValue("FISchutzschalter").set((_Zustand_ & 0x10) >>> 4);
		}
		else {
			debug.warning("StromVersorgungs-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
			              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
			              deBlock.toString());
			return resultData;
		}
		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 52 Id: 4  Name: Heizung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Heizung ok                    Heizung defekt
	 * 1                       ausgeschaltet                 eingeschaltet
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ052Id004AtgTlsVltHeizungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
			case 2:
			case 3:
				data.getUnscaledValue("HeizungStatus").set(_Zustand_ & 0x01);
				data.getUnscaledValue("HeizungBetriebszustand").set((_Zustand_ & 0x02) >>> 1);
				break;
			default:
				debug.warning("Heizungs-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 53 Id: 4  Name: Lüftung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Lüftung ok                    Lüftung defekt
	 * 1                       ausgeschaltet                 eingeschaltet
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ053Id004AtgTlsVltLüftungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
			case 2:
			case 3:
				data.getUnscaledValue("LüftungStatus").set(_Zustand_ & 0x01);
				data.getUnscaledValue("LüftungBetriebszustand").set((_Zustand_ & 0x02) >>> 1);
				break;
			default:
				debug.warning("Lüftungsüberwachungs-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 54 Id: 4  Name: Überspannungsschutz (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       Überspannungsschutz ok        Überspannungsschutz defekt
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ054Id004AtgTlsVltÜberspannungsSchutzAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_Zustand_) {
			case 0:
			case 1:
				data.getUnscaledValue("Überspannungsschutz").set(_Zustand_ & 0x01);
				break;
			default:
				debug.warning("Überspannungsschutz-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 55 Id: 4  Name: Diebstahl-/und Vandalismusschutz (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 3 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                        [ 48 ]
	 * Byte 4           Zustand                                 Zustand siehe unten
	 *
	 * Bit                     Zustand 0                     Zustand 1
	 * 0                       kein Alarm                    Alarm
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ055Id004AtgTlsVltDiebstahlVandalismusSchutzAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
				data.getUnscaledValue("Diebstahl").set(_Zustand_ & 0x01);
				break;
			default:
				debug.warning("Diebstahl-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 6 : Typ: 56 Id: 4  Name: Fernüberwachung von Solaranlagen (Antwort).
	 * <pre>
	 * Position         Bezeichnung                                    Erläuterung
	 * Byte 1           Länge DE-Block                                 Länge des folgenden DE-Blocks [ 5 ]
	 * Byte 2           Daten-Endgeräte-Kanal                          [ 1.. 254 ]
	 * Byte 3           Typ der DE-Daten                               [ 56 ]
	 * Byte 4           Zustand Zustand                                siehe unten
	 * Byte 5           Ladespannung                                   [ 1.. 254 Volt, 255]
	 * Byte 6           Ladestrom                                      [ 1.. 254 in 10mA Schritten, 255]
	 * </pre>
	 * Typ 56: Fernüberwachung von Solaranlagen<br>
	 * <pre>
	 * Bit                     Zustand 0                          Zustand 1
	 * 0                       Überladungsschutz angesprochen     Überladungsschutz nicht angesprochen
	 * 1                       Tiefenladeschutz steht bevor       Tiefenladeschutz steht nicht bevor
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg006Typ056Id004AtgTlsVltFernÜberwachungSolarAnlagenAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Zustand-Byte aus Telegramm ----------------------------------------------------------------------------------
		int _Zustand_ = deBlock.getDeData().readUnsignedByteAsInt();

		switch (_Zustand_) {
			case 0:
			case 1:
			case 2:
			case 3:
				data.getUnscaledValue("SolarÜberladeSchutz").set(_Zustand_ & 0x01);
				data.getUnscaledValue("SolarTiefentladeSchutz").set((_Zustand_ & 0x02) >>> 1);
				break;
			default:
				debug.warning("FernÜberwachungSolarAnlagen-Wert ungültig : " + _Zustand_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// SolarLadeSpannung-Byte aus Telegramm ------------------------------------------------------------------------
		int _SolarLadeSpannung_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("SolarLadeSpannung").set(_SolarLadeSpannung_);

		// SolarLadeStrom-Byte aus Telegramm ---------------------------------------------------------------------------
		int _SolarLadeStrom_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("SolarLadeStrom").set(_SolarLadeStrom_);

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterIst(DeBlock,
	 * Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg255Typ029Id034AtgTlsGloKanalSteuerungAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 2, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterIst(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg006Default#Fg255Typ036Id003AtgTlsGloGeographischeKenndatenAspTlsZustand(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg255Typ036Id035AtgTlsGloGeographischeKenndatenAspTlsZustand(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg255Typ036Id003AtgTlsGloGeographischeKenndatenAspTlsZustand(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}
}
