/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt
 *
 * de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.nw.vrz.Fg002HeuschBoesefeldt wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */

package de.bsvrz.kex.tls.osi7.conversion.nw.vrz;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.IntegerValueState;
import de.bsvrz.kex.tls.osi7.*;
import de.bsvrz.sys.funclib.debug.Debug;

import java.util.*;

/**
 * Umsetungsmodul für die FG 2, Standard (alle Typen der FG 2 gemäß TLS 2002) Wird standardmäßig für alle FG 2 De
 * verwendet, bei denen keine spezielle Umsezungsklasse in der Konfiguration angegeben wurde.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kniß (HCK)
 * @version $Revision$ / $Date$ / ($Author$)
 */

public class Fg002HeuschBoesefeldt extends FgAllHeuschBoesefeldt {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Sonstige ---------------------------------------------------------------
	/**
	 * DebugLogger für Debug-Ausgaben
	 */
	private static final Debug debug = Debug.getLogger();
// Private ----------------------------------------------------------------
	/**
	 * Tabelle, in der das Verhalten beim Empfang von Attributgruppen eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.parameterSoll", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Empfangsanmeldung als Empfänger.</li> <li> In der Methode {@link #update} wird für jede zur
	 * Attributgruppen/Aspket-Kombination passende Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag
	 * wie folgt gebildet wird (hier für den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll(ResultData)</code><br>
	 * Dabei enthält <code>ResultData</code> die Daten der zu verarbeitenden ATG/ASP-Kombination.</li> <li> Für jede
	 * Attributguppen/Aspekt Kombination erfolgt eine Empfangsanmeldung als Empfänger. Sind mehrere passende Eintrage
	 * vorhanden, werden entsprechend mehrere Methodenaufrufe durchgeführt. Dadurch können mehrere ATG/ASP-Kombinationen in
	 * einen De-Block abgebildet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eines Fachmodells):</li>
	 * <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */
	private final Object[][] davToTls = new Object[][]{
			// Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
			{"atg.tlsGloDeBlockAbruf", "asp.tlsAbruf", "255", "255", "255", "typ.deAxl"},
			{"atg.tlsGloDeBlockSenden", "asp.tlsVorgabe", "255", "255", "255", "typ.deAxl"},
			{"atg.tlsGloKanalSteuerung", "asp.parameterSoll", "255", "29", "2", "typ.deAxl"},
			{"atg.tlsGloGeographischeKenndaten", "asp.tlsVorgabe", "255", "36", "3", "typ.deAxl"},
			{"atg.tlsAxlAbrufPufferInhalt", "asp.tlsAbruf", "2", "20", "2", "typ.deAxl"},
			{"atg.tlsAxlAbrufPufferInhaltEinzelErgebnisMeldungen", "asp.tlsAbruf", "2", "21", "2", "typ.deAxl"},
			{"atg.tlsAxlBetriebsParameter", "asp.parameterSoll", "2", "32", "3", "typ.deAxl"},
			{"atg.tlsAxlGrenzWerteFürAchsLastenUndGesamtGewichteÜberladung", "asp.parameterSoll", "2", "37", "3", "typ.deAxl"},
			{"atg.tlsAxlParameterFürAchsUndGewichtsKlassen", "asp.parameterSoll", "2", "38", "3", "typ.deAxl"}
	};

	/**
	 * Tabelle, in der das Verhalten beim Empfang von TLS De-Blöcken eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.tlsAntwort", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Sendeanmeldung als Quelle.</li> <li> In der Methode {@link #processDeBlock} wird für jede zum De-Block passende
	 * Fg/Id/Typ-Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag wie folgt gebildet wird (hier für
	 * den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspTlsAntwort(DeBlock, Data,
	 * DataDescription)</code><br> Dabei enthält der <code>deBlock</code> die Daten des zu verarbeitenden De-Blocks und
	 * <code>data</code> ein Datenobjekt der passenden Attributgruppen/Aspekt-Kombination, welchem direkt die Inhalte des
	 * De-Blocks zugewiesen werden können.<code>DataDescription</code> enthält die passende {@link
	 * DataDescription} für die zu sendenden Daten.</li> <li> Für jede Attributguppen/Aspekt
	 * Kombination erfolgt eine Sendeanmeldung als Quelle. Sind mehrere passende Eintrage vorhanden, werden entsprechend
	 * mehrere Methodenaufrufe durchgeführt. Dadurch kann ein De-Block mehrfach ausgewert und an verschiedene
	 * Attributgruppen weitergerleitet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eine
	 * Fachmodells):</li> <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */
	private final Object[][] tlsToDav = new Object[][]{
			// Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
			{"atg.tlsGloDeFehler", "asp.tlsAntwort", "2", "1", "1", "typ.deAxl"},
			{"atg.tlsGloKanalSteuerung", "asp.parameterIst", "255", "29", "2", "typ.deAxl"},
			{"atg.tlsGloGeographischeKenndaten", "asp.tlsZustand", "255", "36", "3", "typ.deAxl"},
			{"atg.tlsAxlErgänzendeDeFehlerMeldung", "asp.tlsAntwort", "2", "14", "1", "typ.deAxl"},
			{"atg.tlsAxlNegativeQuittung", "asp.tlsAntwort", "2", "16", "2", "typ.deAxl"},
			{"atg.tlsAxlBetriebsParameter", "asp.parameterIst", "2", "32", "3", "typ.deAxl"},
			{"atg.tlsAxlGrenzWerteFürAchsLastenUndGesamtGewichteÜberladung", "asp.parameterIst", "2", "37", "3", "typ.deAxl"},
			{"atg.tlsAxlParameterFürAchsUndGewichtsKlassen", "asp.parameterIst", "2", "38", "3", "typ.deAxl"},
			{"atg.tlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2", "asp.tlsAntwort", "2", "60", "4", "typ.deAxl"},
			{"atg.tlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2", "asp.tlsAntwort", "2", "61", "4", "typ.deAxl"},
			{"atg.tlsAxlErgebnisMeldungAchsLastDatenVersion10", "asp.tlsAntwort", "2", "65", "4", "typ.deAxl"},
			{"atg.tlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2", "asp.tlsAntwort", "2", "60", "36", "typ.deAxl"},
			{"atg.tlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2", "asp.tlsAntwort", "2", "61", "36", "typ.deAxl"},
			{"atg.tlsAxlErgebnisMeldungAchsLastDatenVersion10", "asp.tlsAntwort", "2", "65", "36", "typ.deAxl"}
	};

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt ein Objekt vom Typ Fg001Default
	 *
	 * @param daf DaV
	 * @param eak Eak
	 * @param de De
	 */
	public Fg002HeuschBoesefeldt(ClientDavInterface daf, Eak eak, De de) {
		super(daf, eak, de);
		subscribeAllData(tlsToDav, davToTls);
	}

// ------------------------------------------------------------------------
// SONSTIGE METHODEN
// ------------------------------------------------------------------------

	/**
	 * FG 2 : Typ: 1 Id: 1 Name: DE-Fehler (Antwort). Ergänzt globale Behandlung De-Fehler in {@link
	 * #Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort}. Beim Empfang einer De-Gutmeldung wird die De initialisiert, indem
	 * <ul> <li>AXL-kanalsteuerung {@link #Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll}</li>
	 * <li>AXL-betriebsparameter{@link #Fg002Typ032Id003AtgTlsAxlBetriebsParameterAspParameterSoll}</li> </ul> versendet
	 * werden.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = super.Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(deBlock, data, dataDescription);

		IntegerValueState DEFehlerStatus = data.getUnscaledValue("DEFehlerStatus").getState();
		if (DEFehlerStatus != null) {
			debug.fine("DEFehlerStatus: " + DEFehlerStatus.getName());
			if (DEFehlerStatus.getName().equals("ok")) {
				// Bei der Kommunikation mit der VRZ werden keine Daten bei De=ok versendet.
				// sendInitialDeBlock(deBlock.getKey(), 29, 2); // AXL-Kanalsteuerung senden
				// sendInitialDeBlock(deBlock.getKey(), 32, 3); // AXL-Betriebsparameter senden
			}
			else {
				List deList = new ArrayList();
				deList.add(_de);
				TlsApplicationLayer.writeNoDataToUnreachableDe(deList, _eakConversionModul.getTimeStamp(), -1, "atg.tlsGloDeFehler");
			}
		}
		return resultData;
	}

	/**
	 * FG 2 : Typ: 14 Id: 1 Name: Ergänzende DE-Fehlermeldung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          [ 9..29 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 14 ]
	 * Byte 4           Herstellercode                          (s. Anh. 7, Kap. 2)
	 * Byte 5           Anzahl TLS - Fehlerbytes                [ 4 ]
	 * Byte 6           TLS - Fehlerbyte 1                      Codierung siehe unten
	 * Byte 7           TLS - Fehlerbyte 2                      Codierung siehe unten
	 * Byte 8           TLS - Fehlerbyte 3                      Codierung siehe unten
	 * Byte 9           TLS - Fehlerbyte 4                      Codierung siehe unten
	 * Byte 10          Anzahl Hersteller Fehlerbytes           [ 0..20 ]
	 * Byte 11          Hersteller-Fehlerbyte 1                 herstellerspez. Codierung
	 * Byte..           Hersteller-Fehlerbyte n                 herstellerspez. Codierung
	 * </pre>
	 * <br> Inhalt TLS-Fehlerbytes:<br> Die Fehlerbytes sind bitweise codiert. Jedes Bit definiert einen bestimmten Fehler,
	 * wobei das Bit gleich 1 gesetzt ist.<br> Es können auch mehrere Bit gleichzeitig gesetzt werden. Für spätere
	 * Definitionen reservierte Bits sind gleich Null zu setzen.<br>
	 * <pre>
	 *         Bit 7      Bit 6       Bit 5       Bit 4          Bit 3         Bit 2       Bit 1       Bit 0
	 * Byte 1  Reserve    Reserve     RNR am      Lokalbus       Reserve       Reserve     Reserve     Teilstörung
	 *                                Lokalbus1   ausgefallen
	 * Byte 2  Reserve    Reserve     Reserve     Reserve        Detektor      Achslast-   Detektor    Subbus
	 *                                                           Abgleich      sensor      gestört     ausgefallen
	 *                                                                         gestört
	 * Byte 3  Reserve    Reserve     Reserve     Reserve        Reserve       Reserve     Reserve     Reserve
	 * Byte 4  Reserve    Reserve     Reserve     Reserve        Reserve       Reserve     Reserve     Reserve
	 * 1) nur in Verbindung mit Stö/SM=1 im Byte 4 der DE-Block-Struktur im Typ 1
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ014Id001AtgTlsLveErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Herstellercode-Byte aus Telegramm ---------------------------------------------------------------------------
		int _Herstellercode_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("Hersteller").set(_Herstellercode_);

		// Fehler-Bytes aus Telegramm -----------------------------------------------------------------------------------
		deBlock.getDeData().readUnsignedByteAsInt(); // Anzahl der folgenden Bytes überlesen, da immer == 4 !
		int _TlsFehler1_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler2_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler3_ = deBlock.getDeData().readUnsignedByteAsInt();
		int _TlsFehler4_ = deBlock.getDeData().readUnsignedByteAsInt();

		Data.NumberArray _TlsFehler_ = data.getItem("FehlercodesTLS").getUnscaledArray("Fehler");
		_TlsFehler_.setLength(4);
		_TlsFehler_.getValue(0).set(_TlsFehler1_);
		_TlsFehler_.getValue(1).set(_TlsFehler2_);
		_TlsFehler_.getValue(2).set(_TlsFehler3_);
		_TlsFehler_.getValue(3).set(_TlsFehler4_);

		// Hersteller Fehler-Bytes aus Telegramm -----------------------------------------------------------------------
		int count = deBlock.getDeData().readUnsignedByteAsInt();
		int[] _HerstellerFehler_ = new int[count];
		for (int i = 0; i < count; i++) {
			_HerstellerFehler_[i] = deBlock.getDeData().readUnsignedByteAsInt();
		}

		Data.NumberArray _Fehler_ = data.getItem("FehlercodesHersteller").getUnscaledArray("Fehler");
		_Fehler_.setLength(count);
		for (int i = 0; i < count; i++) {
			_Fehler_.getValue(i).set(_HerstellerFehler_[i]);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 2 : Typ: 16 Id: 2 Name: Negative Quittung (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 4 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 16 ]
	 * Byte 4           Fehlerursache                           siehe unten
	 * Byte 5           Herstellercode                          siehe Liste in Anhang 7, Kap. 2
	 * </pre>
	 * Inhalt Byte: Fehlerursache unter FG 2:
	 * <pre>
	 *        0: sonstige Fehlerursache
	 *        1: unbekannte oder nicht auswertbare ID
	 *        2: unbekannter oder nicht auswertbarer Typ
	 *        3: Version nicht verfügbar
	 *    4..11: reserviert für spätere Definitionen
	 *       12: Pufferinhalt nicht verfügbar
	 *   13..14: reserviert für spätere Definitionen
	 *       15: Kanal passiviert
	 *  16..127: reserviert für spätere Definitionen
	 * 128..255: frei für herstellerdefinierte Ursachencodes
	 * </pre>
	 * Inhalt Byte Herstellercode<br> Der Herstellercode ist ein für jeden Hersteller eindeutig zugeordneter Code, der der
	 * Zentrale die Zuordnung der Nachrichten erleichtern soll.<br>.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ016Id002AtgTlsLveNegativeQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		return super.Fg255Typ016Id002AtgTlsGloNegativeQuittungAspTlsAntwort(deBlock, data, dataDescription);
	}

	/**
	 * FG 2 : Typ: 20 Id: 2 Name: Abruf Pufferinhalt Ergebnismeldungen (Abruf). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 7 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 255 ]
	 * Byte 3           Typ der DE-Daten                        [ 20 ]
	 * Byte 4           Jahr                                    [ 00..99 ]
	 * Byte 5           Monat                                   [ 1..12 ]
	 * Byte 6           Tag                                     [ 1..31 ]
	 * Byte 7           Stunde                                  [ 0/1 *128 + 0..23 ]
	 * Byte 8           Minute                                  [ 0..59 ]
	 * Byte 9           Anzahl angeforderter Datensätze         [ 1..5 ]
	 * </pre>
	 * Inhalt Byte Stunde
	 * <pre>
	 * Bit 0...6: Angabe der Stunde, binär codiert
	 * Bit 7 = 0: Normalzeit (MEZ)
	 * Bit 7 = 1: Sommerzeit (MESZ)
	 * </pre>
	 * Inhalt Byte Anzahl angeforderter Datensätze:<br> Gibt die Anzahl der zu übertragenden Datensätze an. Dabei wird ab
	 * dem durch die Zeitangabe festgelegten Datensatz in Richtung des aktuellen Datensatzes gezählt.<br> Der älteste der
	 * geforderten Datensätze wird auch zuerst übertragen.<br> Die Anzahl der geforderten Datensätze darf von der Zentrale
	 * nicht zu groß gewählt werden, da sonst die Busverbindung durch diese Übertragung zu lange belegt wird.<br> Beim
	 * Auslesen über eine Schnittstelle im Gerät (Rechner- oder Serviceschnittstelle) darf die Anzahl zwischen 1 und 255
	 * liegen.<br>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg002Typ020Id002AtgTlsAxlAbrufPufferInhaltAspTlsAbruf(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _Jahr_;
		int _Monat_;
		int _Tag_;
		int _Stunde_;
		int _Anzahl_;

		// Umsetzung

		Data data = result.getData(); // Datensatz holen

		long _Zeitpunkt_ = data.getTimeValue("Zeitpunkt").getMillis();
		GregorianCalendar gregorianCalendar = new GregorianCalendar();
		gregorianCalendar.setTimeInMillis(_Zeitpunkt_);

		_Jahr_ = (gregorianCalendar.get(Calendar.YEAR) - 2000);
		_Monat_ = (gregorianCalendar.get(Calendar.MONTH) + 1);
		_Tag_ = gregorianCalendar.get(Calendar.DAY_OF_MONTH);
		_Stunde_ = gregorianCalendar.get(Calendar.HOUR_OF_DAY);
		if (gregorianCalendar.get(Calendar.DST_OFFSET) > 0) {
			_Stunde_ += 128;
		}

		debug.finest("Abrufzeit Puffer (" + gregorianCalendar.getTime() + "): " +
		             "Jahr: " + _Jahr_ + " Monat: " + _Monat_ + " Tag: " + _Tag_ + " Stunde: " + _Stunde_);

		_Anzahl_ = data.getUnscaledValue("Anzahl").intValue();

		// DeBlock als TlsData aufbauen...

		TlsData deApplicationData = new TlsData(5);
		deApplicationData.writeIntAsByte(_Jahr_);
		deApplicationData.writeIntAsByte(_Monat_);
		deApplicationData.writeIntAsByte(_Tag_);
		deApplicationData.writeIntAsByte(_Stunde_);
		deApplicationData.writeIntAsByte(_Anzahl_);

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 20, 2, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * FG 2 : Typ: 21 Id: 2 Name: Abruf Pufferinhalt Einzelergebnismeldungen (Abruf). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 11 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 255 ]
	 * Byte 3           Typ der DE-Daten                        [ 21 ]
	 * Byte 4           Jahr                                    [ 0..9999 ] low Byte
	 * Byte 5           Jahr                                    high Byte
	 * Byte 6           Monat                                   [ 1..12 ]
	 * Byte 7           Tag                                     [ 1..31 ]
	 * Byte 8           Stunde                                  [ 0/1 *128 + 0..23 ]
	 * Byte 9           Minute                                  [ 0..59 ]
	 * Byte 10          Sekunde                                 [ 0..59 ]
	 * Byte 11          Anzahl angeforderter Datensätze         [ 1..65534, 65535 ] low Byte
	 * Byte 12          Anzahl angeforderter Datensätze         high Byte
	 * </pre>
	 * Inhalt Byte Stunde:
	 * <pre>
	 * Bit 0...6: Angabe der Stunde, binär codiert
	 * Bit 7 = 0: Normalzeit (MEZ)
	 * Bit 7 = 1: Sommerzeit (MESZ)
	 * </pre>
	 * Inhalt Byte Anzahl angeforderter Datensätze:<br> Gibt die Anzahl der zu übertragenden Datensätze an. Dabei wird ab
	 * dem durch die Zeitangabe festgelegten Datensatz in Richtung des aktuellen Datensatzes gezählt.<br> Der älteste der
	 * geforderten Datensätze wird auch zuerst übertragen.<br> Die Anzahl der angeforderten Datensätze kann zwischen 1 und
	 * 65534 liegen. Mit 65535 werden alle Datensätze ab dem angegebenen Zeitpunkt aus dem Puffer übertragen. Die Anzahl
	 * der geforderten Datensätze muss von der Zentrale entsprechend der Kapazität der Verbindung gewählt werden.<br> Beim
	 * Auslesen über eine Schnittstelle im Gerät (Rechner- oder Serviceschnittstelle) ist dies unkritisch.<br>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg002Typ021Id002AtgTlsAxlAbrufPufferInhaltEinzelErgebnisMeldungenAspTlsAbruf(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _Jahr_;
		int _Monat_;
		int _Tag_;
		int _Stunde_;
		int _Minute_;
		int _Sekunde_;
		int _Anzahl_;

		// Umsetzung

		Data data = result.getData(); // Datensatz holen

		long _Zeitpunkt_ = data.getTimeValue("Zeitpunkt").getMillis();
		GregorianCalendar gregorianCalendar = new GregorianCalendar();
		gregorianCalendar.setTimeInMillis(_Zeitpunkt_);

		_Jahr_ = (gregorianCalendar.get(Calendar.YEAR) - 2000);
		_Monat_ = (gregorianCalendar.get(Calendar.MONTH) + 1);
		_Tag_ = (gregorianCalendar.get(Calendar.DAY_OF_MONTH));
		_Stunde_ = (gregorianCalendar.get(Calendar.HOUR_OF_DAY));
		if (gregorianCalendar.get(Calendar.DST_OFFSET) > 0) {
			_Stunde_ += 128;
		}
		_Minute_ = (gregorianCalendar.get(Calendar.MINUTE));
		_Sekunde_ = (gregorianCalendar.get(Calendar.SECOND));

		debug.finest("Abrufzeit Puffer (" + gregorianCalendar.getTime() + "): " +
		             "Jahr: " + _Jahr_ + " Monat: " + _Monat_ + " Tag: " + _Tag_ + " Stunde: " + _Stunde_ +
		             "Minute: " + _Minute_ + "Sekunde: " + _Sekunde_);

		_Anzahl_ = data.getUnscaledValue("Anzahl").intValue();

		// DeBlock als TlsData aufbauen...

		TlsData deApplicationData = new TlsData(9);
		deApplicationData.writeIntAsLowHighByte(_Jahr_);
		deApplicationData.writeIntAsByte(_Monat_);
		deApplicationData.writeIntAsByte(_Tag_);
		deApplicationData.writeIntAsByte(_Stunde_);
		deApplicationData.writeIntAsByte(_Minute_);
		deApplicationData.writeIntAsByte(_Sekunde_);
		deApplicationData.writeIntAsLowHighByte(_Anzahl_);

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 20, 2, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * FG 2 : Typ: 32 Id: 3 Name:Betriebsparameter (Abruf / Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          [ 9 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [1..254, 255]
	 * Byte 3           Typ der DE-Daten                        [ 32 ]
	 * Byte 4           reserviert                              [ 0 ]
	 * Byte 5           reserviert                              [ 0 ]
	 * Byte 6           Datenversion Ergebnismeldung            [ 10, 255= aus ]
	 * Byte 7           Erfassungsintervalldauer                siehe unten
	 * Byte 8           reserviert                              [ 0 ]
	 * Byte 9           Datenversion Einzelergebnismeldung      [1,2; 255= aus ]
	 * Byte 10          Speicherung im Gerät                    siehe unten
	 * </pre>
	 * Inhalt Byte Datenversion Ergebnismeldung:<br> Der Inhalt des Bytes bestimmt die Version der Ergebnismeldung, die
	 * übertragen werden soll. Mit dem Wert 255 lässt sich die Übertragung der Ergebnismeldungen abschalten.<br> <br>
	 * Inhalt Byte Erfassungsintervalldauer: Das Byte enthält den Wert der Erfassungsintervalldauer in folgenden
	 * Zeiteinheiten:<br>
	 * <pre>
	 * Bit7 = 1:  Einheit = Stunde
	 * Bit0..6:   Zeitwert in Stunden [1..120]
	 * </pre>
	 * Es sind nur Stundenwerte zugelassen, die ganzzahlige Teiler oder ganzzahlige Mehrfache von 24 Stunden sind (1, 2, 3,
	 * 4, 6, 8, 12, 24, 48, 72, 96, 120 Stunden).<br>
	 * <pre>
	 * Bit7 = 0:  Einheit = ¼ - Stunde
	 * Bit0..6:   Zeitwert in ¼ -Stunden [1..120]
	 * </pre>
	 * Es sind nur ¼ -Stundenwerte zugelassen, die ganzzahlige Teiler von 24 Stunden sind (1, 2, 3, 4, 6, 8, 12, 16, 24,
	 * 32, 48, 96 ¼ - Stunden)<br> <br> Inhalt Byte: Datenversion Einzelergebnismeldung<br> Der Inhalt des Bytes bestimmt
	 * die Version der Einzelergebnismeldung, die übertragen werden soll. Mit dem Wert 255 lässt sich die Übertragung der
	 * Einzelergebnismeldungen abschalten. Der Wert 0 ist reserviert; es erfolgt ebenfalls keine Übertragung.<br> <br>
	 * Inhalt Byte: Speicherung im Gerät<br> Für Sonderuntersuchungen lassen sich im Gerät verschiedene Daten speichern,
	 * die nicht on-line übertragen werden. Unabhängig von dieser Erfassung läuft die Übertragung der Ergebnismeldungen und
	 * Einzelergebnismeldungen, wie in den Bytes "Datenversion" eingestellt, weiter. Die gespeicherten Daten lassen sich am
	 * Gerät oder on-line mit der DEBlock- Struktur Typ 21 abrufen.<br> Mit diesem Byte kann die Speicherung im Gerät
	 * gesteuert werden. Dabei ist jeder Aufzeichnungsart ein Code nach folgender Liste zugeordnet:
	 * <pre>
	 *           0: keine Speicherung der Einzelachslastdaten
	 *           1: Aufzeichnung aller Einzelachslasten aller Fahrzeuge einschließlich
	 *              Pkw
	 *           2: Aufzeichnung aller Einzelachslasten aller Fahrzeuge ohne Pkw
	 *      3..255: reserviert für spätere Definitionen
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ032Id003AtgTlsAxlBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Leerbytes überlesen
		deBlock.getDeData().readUnsignedByteAsInt();
		deBlock.getDeData().readUnsignedByteAsInt();

		// DatenversionErgebnisMeldung-Byte aus Telegramm --------------------------------------------------------------
		int _DatenversionErgebnisMeldung_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_DatenversionErgebnisMeldung_) {
			case 10:
			case 255:
				data.getUnscaledValue("DatenversionErgebnisMeldung").set(_DatenversionErgebnisMeldung_);
				break;

			default:
				debug.warning("DatenversionErgebnisMeldung-Wert ungültig : " + _DatenversionErgebnisMeldung_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Erfassungsintervalldauer-Byte aus Telegramm -----------------------------------------------------------------
		int _Erfassungsintervalldauer_ = deBlock.getDeData().readUnsignedByteAsInt();

		// Intervalldauer auf 1/4 Stunde umrechnen und auf Gültigkeit prüfen

		if (_Erfassungsintervalldauer_ > 127) { // Stundenbit gesetzt
			_Erfassungsintervalldauer_ = (_Erfassungsintervalldauer_ & 0x7f) * 4;
		}
		switch (_Erfassungsintervalldauer_) {
			case 1:
			case 2:
			case 3:
			case 4:
			case 6:
			case 8:
			case 12:
			case 16:
			case 24:
			case 32:
			case 48:
			case 96:
			case 192:
			case 288:
			case 384:
			case 480:

				data.getUnscaledValue("Erfassungsintervalldauer").set(_Erfassungsintervalldauer_);
				break;

			default:
				debug.warning("Erfassungsintervalldauer-Wert ungültig : " + _Erfassungsintervalldauer_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Leerbyte überlesen
		deBlock.getDeData().readUnsignedByteAsInt();

		// DatenversionEinzelErgebnisMeldung-Byte aus Telegramm --------------------------------------------------------------
		int _DatenversionEinzelErgebnisMeldung_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_DatenversionErgebnisMeldung_) {
			case 0:
			case 1:
			case 2:
				data.getUnscaledValue("DatenversionEinzelErgebnisMeldung").set(_DatenversionEinzelErgebnisMeldung_);
				break;

			default:
				debug.warning("DatenversionEinzelErgebnisMeldung-Wert ungültig : " + _DatenversionEinzelErgebnisMeldung_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// SpeicherungImGerät-Byte aus Telegramm --------------------------------------------------------------
		int _SpeicherungImGerät_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_DatenversionErgebnisMeldung_) {
			case 0:
			case 1:
			case 2:
			case 255:
				data.getUnscaledValue("SpeicherungImGerät").set(_SpeicherungImGerät_);
				break;

			default:
				debug.warning("SpeicherungImGerät-Wert ungültig : " + _SpeicherungImGerät_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 2 : Typ: 32 Id: 3 Name:Betriebsparameter (Abruf / Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          [ 9 ]
	 * Byte 2           Daten-Endgeräte-Kanal                   [1..254, 255]
	 * Byte 3           Typ der DE-Daten                        [ 32 ]
	 * Byte 4           reserviert                              [ 0 ]
	 * Byte 5           reserviert                              [ 0 ]
	 * Byte 6           Datenversion Ergebnismeldung            [ 10, 255= aus ]
	 * Byte 7           Erfassungsintervalldauer                siehe unten
	 * Byte 8           reserviert                              [ 0 ]
	 * Byte 9           Datenversion Einzelergebnismeldung      [1,2; 255= aus ]
	 * Byte 10          Speicherung im Gerät                    siehe unten
	 * </pre>
	 * Inhalt Byte Datenversion Ergebnismeldung:<br> Der Inhalt des Bytes bestimmt die Version der Ergebnismeldung, die
	 * übertragen werden soll. Mit dem Wert 255 lässt sich die Übertragung der Ergebnismeldungen abschalten.<br> <br>
	 * Inhalt Byte Erfassungsintervalldauer: Das Byte enthält den Wert der Erfassungsintervalldauer in folgenden
	 * Zeiteinheiten:<br>
	 * <pre>
	 * Bit7 = 1:  Einheit = Stunde
	 * Bit0..6:   Zeitwert in Stunden [1..120]
	 * </pre>
	 * Es sind nur Stundenwerte zugelassen, die ganzzahlige Teiler oder ganzzahlige Mehrfache von 24 Stunden sind (1, 2, 3,
	 * 4, 6, 8, 12, 24, 48, 72, 96, 120 Stunden).<br>
	 * <pre>
	 * Bit7 = 0:  Einheit = ¼ - Stunde
	 * Bit0..6:   Zeitwert in ¼ -Stunden [1..120]
	 * </pre>
	 * Es sind nur ¼ -Stundenwerte zugelassen, die ganzzahlige Teiler von 24 Stunden sind (1, 2, 3, 4, 6, 8, 12, 16, 24,
	 * 32, 48, 96 ¼ - Stunden)<br> <br> Inhalt Byte: Datenversion Einzelergebnismeldung<br> Der Inhalt des Bytes bestimmt
	 * die Version der Einzelergebnismeldung, die übertragen werden soll. Mit dem Wert 255 lässt sich die Übertragung der
	 * Einzelergebnismeldungen abschalten. Der Wert 0 ist reserviert; es erfolgt ebenfalls keine Übertragung.<br> <br>
	 * Inhalt Byte: Speicherung im Gerät<br> Für Sonderuntersuchungen lassen sich im Gerät verschiedene Daten speichern,
	 * die nicht on-line übertragen werden. Unabhängig von dieser Erfassung läuft die Übertragung der Ergebnismeldungen und
	 * Einzelergebnismeldungen, wie in den Bytes "Datenversion" eingestellt, weiter. Die gespeicherten Daten lassen sich am
	 * Gerät oder on-line mit der DEBlock- Struktur Typ 21 abrufen.<br> Mit diesem Byte kann die Speicherung im Gerät
	 * gesteuert werden. Dabei ist jeder Aufzeichnungsart ein Code nach folgender Liste zugeordnet:
	 * <pre>
	 *           0: keine Speicherung der Einzelachslastdaten
	 *           1: Aufzeichnung aller Einzelachslasten aller Fahrzeuge einschließlich
	 *              Pkw
	 *           2: Aufzeichnung aller Einzelachslasten aller Fahrzeuge ohne Pkw
	 *      3..255: reserviert für spätere Definitionen
	 * </pre>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg002Typ032Id003AtgTlsAxlBetriebsParameterAspParameterSoll(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _DatenversionErgebnisMeldung_;
		int _Erfassungsintervalldauer_;
		int _DatenversionEinzelErgebnisMeldung_;
		int _SpeicherungImGerät_;

		// Umsetzung
		Data data = result.getData(); // Datensatz holen

		_DatenversionErgebnisMeldung_ = data.getUnscaledValue("DatenversionErgebnisMeldung").intValue();
		// Intervalldauer ist in 1/4 Stunden kodiert. Ist der Wert > 96 1/4h, so Angabe in Stunden mit Stundenbit.
		_Erfassungsintervalldauer_ = data.getUnscaledValue("Erfassungsintervalldauer").intValue();
		if (_Erfassungsintervalldauer_ > 96) {
			_Erfassungsintervalldauer_ = ((_Erfassungsintervalldauer_ / 4) + 0x80);
		}

		_DatenversionEinzelErgebnisMeldung_ = data.getUnscaledValue("DatenversionEinzelErgebnisMeldung").intValue();
		_SpeicherungImGerät_ = data.getUnscaledValue("SpeicherungImGerät").intValue();


		// DeBlock als TlsData aufbauen...

		TlsData deApplicationData = new TlsData(7);
		deApplicationData.writeIntAsByte(0);
		deApplicationData.writeIntAsByte(0);
		deApplicationData.writeIntAsByte(_DatenversionErgebnisMeldung_);
		deApplicationData.writeIntAsByte(_Erfassungsintervalldauer_);
		deApplicationData.writeIntAsByte(0);
		deApplicationData.writeIntAsByte(_DatenversionEinzelErgebnisMeldung_);
		deApplicationData.writeIntAsByte(_SpeicherungImGerät_);

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 32, 3, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * FG 2 : Typ: 37 Id: 3 Name: Grenzwerte für Achslasten und Gesamtgewichte (Überladung) (Abruf / Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                                       Erläuterung
	 * Byte 1           Länge DE-Block                                    [ Länge des folgenden Blocks ]
	 * Byte 2           Daten-Endgeräte-Kanal                             [1..254, 255]
	 * Byte 3           Typ der DE-Daten                                  [ 37 ]
	 * Byte 4           Höchstzulässige Einzelachslast, 1.Achse           [ 0.. 65534 kg, 65535] low Byte
	 * Byte 5           Höchstzulässige Einzelachslast, 1.Achse           high Byte
	 * Byte 6           Höchstzulässige Einzelachslast                    [ 0.. 65534 kg, 65535] low Byte
	 * Byte 7           Höchstzulässige Einzelachslast                    high Byte
	 * Byte 8           Max. Achsabstand 1 bei Doppelachse                [0..254 cm, 255]
	 * Byte 9           Achsabstand 1: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 10          Achsabstand 1: Höchstzulässige Doppelachslast     high Byte
	 * Byte 11          Max. Achsabstand 2 bei Doppelachse                [0..254 cm, 255]
	 * Byte 12          Achsabstand 2: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 13          Achsabstand 2: Höchstzulässige Doppelachslast     high Byte
	 * Byte 14          Max. Achsabstand 3 bei Doppelachse                [0..254 cm, 255]
	 * Byte 15          Achsabstand 3: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 16          Achsabstand 3: Höchstzulässige Doppelachslast     high Byte
	 * Byte 17          Max. Achsabstand 1 bei Dreifachachse              [0..254 cm, 255]
	 * Byte 18          Achsabstand 1: Höchstzulässige Dreifachachslast   [ 0.. 65534 kg, 65535] low Byte
	 * Byte 19          Achsabstand 1: Höchstzulässige Dreifachachslast   high Byte
	 * Byte 20          Max. Achsabstand 2 bei Dreifachachse              [0..254 cm, 255]
	 * Byte 21          Achsabstand 2: Höchstzulässige Dreifachachslast   [ 0.. 65534 kg, 65535] low Byte
	 * Byte 22          Achsabstand 2: Höchstzulässige Dreifachachslast   high Byte
	 * Byte 23          Anzahl der folgenden Fahrzeugtypen                [1..65]
	 * Byte 24          Code des 1. Fahrzeugtyps                          [8..255] s. Anhang 2, Kapitel 3
	 * Byte 25          Höchstzul. Gesamtgewicht für 1. Fahrzeugtyp       [ 0.. 65534 kg, 65535] low Byte
	 * Byte 26          Höchstzul. Gesamtgewicht für 1. Fahrzeugtyp       high Byte
	 * ..... ......
	 * Byte ...         Code des n. Fahrzeugtyps                          [8..255] s. Anhang 2, Kapitel 3
	 * Byte ...         Höchstzul. Gesamtgewicht für n. Fahrzeugtyp       [ 0.. 65534 kg, 65535] low Byte
	 * Byte ...         Höchstzul. Gesamtgewicht für n. Fahrzeugtyp       high Byte
	 * </pre>
	 * Inhalt Bytes: Höchstzulässige Achslasten<br> In diesen Bytes werden die höchstzulässigen Achslasten eingegeben,
	 * aufgrund dessen das Zählgerät eine Überladung feststellt. Der Wert 65535 bedeutet keine Höchstgrenze.<br> <br>
	 * Inhalt Bytes: Anzahl Fahrzeugtypen<br> Das Byte enthält die Anzahl der Fahrzeugtypen, für die ein höchstzulässiges
	 * Gesamtgewicht übermittelt werden. I.d.R. folgt für jeden im Anhang 2, Kapitel 3 aufgeführten Fahrzeugtyp des
	 * Schwerverkehrs (ab Code 8) ein Wert.<br> <br> Inhalt Bytes: Höchstzulässiges Gesamtgewicht für einen Fahrzeugtyp<br>
	 * In diesem Byte wird das höchstzulässige Gesamtgewicht für die Ermittlung von Überladungen gesetzt. Dabei werden die
	 * Fahrzeuge anhand ihrer Klasse und Achsanordnung nach Typen unterschieden. (s. Anhang, Kapitel 3)<br> Soll oder kann
	 * für diesen Fahrzeugtyp keine Überladung übermittelt werden, wird 65535 gesetzt. Entsprechend setzt ein DE auf
	 * Abfrage mit ID 19 bei diesen Fahrzeugtypen den Wert 65535.<br>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ037Id003AtgTlsAxlGrenzWerteFürAchsLastenUndGesamtGewichteÜberladungAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		int _MaxEinzelachlastErsteAchse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxEinzelachlastErsteAchse").set(_MaxEinzelachlastErsteAchse_);

		int _MaxEinzelachlast_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxEinzelachlast").set(_MaxEinzelachlast_);

		int _MaxAchsabstandDoppelAchse1_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("MaxAchsabstandDoppelAchse1").set(_MaxAchsabstandDoppelAchse1_);

		int _MaxDoppelachlastAchsabstand1_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxDoppelachlastAchsabstand1").set(_MaxDoppelachlastAchsabstand1_);

		int _MaxAchsabstandDoppelAchse2_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("MaxAchsabstandDoppelAchse2").set(_MaxAchsabstandDoppelAchse2_);

		int _MaxDoppelachlastAchsabstand2_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxDoppelachlastAchsabstand2").set(_MaxDoppelachlastAchsabstand2_);

		int _MaxAchsabstandDoppelAchse3_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("MaxAchsabstandDoppelAchse3").set(_MaxAchsabstandDoppelAchse3_);

		int _MaxDoppelachlastAchsabstand3_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxDoppelachlastAchsabstand3").set(_MaxDoppelachlastAchsabstand3_);

		int _MaxAchsabstandDreifachAchse1_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("MaxAchsabstandDreifachAchse1").set(_MaxAchsabstandDreifachAchse1_);

		int _MaxDreifachachlastAchsabstand1_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxDreifachachlastAchsabstand1").set(_MaxDreifachachlastAchsabstand1_);

		int _MaxAchsabstandDreifachAchse2_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("MaxAchsabstandDreifachAchse2").set(_MaxAchsabstandDreifachAchse2_);

		int _MaxDreifachachlastAchsabstand2_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("MaxDreifachachlastAchsabstand2").set(_MaxDreifachachlastAchsabstand2_);

		int count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GesamtgewichtFahrzeugtypen").setLength(count);

		int _FahrzeugklassecodeAchslast_;
		int _MaxGesamtgewicht_;

		for (int i = 0; i < count; ++i) {
			_FahrzeugklassecodeAchslast_ = deBlock.getDeData().readUnsignedByteAsInt();
			data.getArray("GesamtgewichtFahrzeugtypen").getItem(i).getUnscaledValue("FahrzeugklassecodeAchslast").set(_FahrzeugklassecodeAchslast_);
			_MaxGesamtgewicht_ = deBlock.getDeData().readUnsignedByteAsInt();
			data.getArray("GesamtgewichtFahrzeugtypen").getItem(i).getUnscaledValue("MaxGesamtgewicht").set(_MaxGesamtgewicht_);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 2 : Typ: 37 Id: 3 Name: Grenzwerte für Achslasten und Gesamtgewichte (Überladung) (Abruf / Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                                       Erläuterung
	 * Byte 1           Länge DE-Block                                    [ Länge des folgenden Blocks ]
	 * Byte 2           Daten-Endgeräte-Kanal                             [1..254, 255]
	 * Byte 3           Typ der DE-Daten                                  [ 37 ]
	 * Byte 4           Höchstzulässige Einzelachslast, 1.Achse           [ 0.. 65534 kg, 65535] low Byte
	 * Byte 5           Höchstzulässige Einzelachslast, 1.Achse           high Byte
	 * Byte 6           Höchstzulässige Einzelachslast                    [ 0.. 65534 kg, 65535] low Byte
	 * Byte 7           Höchstzulässige Einzelachslast                    high Byte
	 * Byte 8           Max. Achsabstand 1 bei Doppelachse                [0..254 cm, 255]
	 * Byte 9           Achsabstand 1: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 10          Achsabstand 1: Höchstzulässige Doppelachslast     high Byte
	 * Byte 11          Max. Achsabstand 2 bei Doppelachse                [0..254 cm, 255]
	 * Byte 12          Achsabstand 2: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 13          Achsabstand 2: Höchstzulässige Doppelachslast     high Byte
	 * Byte 14          Max. Achsabstand 3 bei Doppelachse                [0..254 cm, 255]
	 * Byte 15          Achsabstand 3: Höchstzulässige Doppelachslast     [ 0.. 65534 kg, 65535] low Byte
	 * Byte 16          Achsabstand 3: Höchstzulässige Doppelachslast     high Byte
	 * Byte 17          Max. Achsabstand 1 bei Dreifachachse              [0..254 cm, 255]
	 * Byte 18          Achsabstand 1: Höchstzulässige Dreifachachslast   [ 0.. 65534 kg, 65535] low Byte
	 * Byte 19          Achsabstand 1: Höchstzulässige Dreifachachslast   high Byte
	 * Byte 20          Max. Achsabstand 2 bei Dreifachachse              [0..254 cm, 255]
	 * Byte 21          Achsabstand 2: Höchstzulässige Dreifachachslast   [ 0.. 65534 kg, 65535] low Byte
	 * Byte 22          Achsabstand 2: Höchstzulässige Dreifachachslast   high Byte
	 * Byte 23          Anzahl der folgenden Fahrzeugtypen                [1..65]
	 * Byte 24          Code des 1. Fahrzeugtyps                          [8..255] s. Anhang 2, Kapitel 3
	 * Byte 25          Höchstzul. Gesamtgewicht für 1. Fahrzeugtyp       [ 0.. 65534 kg, 65535] low Byte
	 * Byte 26          Höchstzul. Gesamtgewicht für 1. Fahrzeugtyp       high Byte
	 * ..... ......
	 * Byte ...         Code des n. Fahrzeugtyps                          [8..255] s. Anhang 2, Kapitel 3
	 * Byte ...         Höchstzul. Gesamtgewicht für n. Fahrzeugtyp       [ 0.. 65534 kg, 65535] low Byte
	 * Byte ...         Höchstzul. Gesamtgewicht für n. Fahrzeugtyp       high Byte
	 * </pre>
	 * Inhalt Bytes: Höchstzulässige Achslasten<br> In diesen Bytes werden die höchstzulässigen Achslasten eingegeben,
	 * aufgrund dessen das Zählgerät eine Überladung feststellt. Der Wert 65535 bedeutet keine Höchstgrenze.<br> <br>
	 * Inhalt Bytes: Anzahl Fahrzeugtypen<br> Das Byte enthält die Anzahl der Fahrzeugtypen, für die ein höchstzulässiges
	 * Gesamtgewicht übermittelt werden. I.d.R. folgt für jeden im Anhang 2, Kapitel 3 aufgeführten Fahrzeugtyp des
	 * Schwerverkehrs (ab Code 8) ein Wert.<br> <br> Inhalt Bytes: Höchstzulässiges Gesamtgewicht für einen Fahrzeugtyp<br>
	 * In diesem Byte wird das höchstzulässige Gesamtgewicht für die Ermittlung von Überladungen gesetzt. Dabei werden die
	 * Fahrzeuge anhand ihrer Klasse und Achsanordnung nach Typen unterschieden. (s. Anhang, Kapitel 3)<br> Soll oder kann
	 * für diesen Fahrzeugtyp keine Überladung übermittelt werden, wird 65535 gesetzt. Entsprechend setzt ein DE auf
	 * Abfrage mit ID 19 bei diesen Fahrzeugtypen den Wert 65535.<br>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg002Typ037Id003AtgTlsAxlGrenzWerteFürAchsLastenUndGesamtGewichteÜberladungAspParameterSoll(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _MaxEinzelachlastErsteAchse_;
		int _MaxEinzelachlast_;
		int _MaxAchsabstandDoppelAchse1_;
		int _MaxDoppelachlastAchsabstand1_;
		int _MaxAchsabstandDoppelAchse2_;
		int _MaxDoppelachlastAchsabstand2_;
		int _MaxAchsabstandDoppelAchse3_;
		int _MaxDoppelachlastAchsabstand3_;
		int _MaxAchsabstandDreifachAchse1_;
		int _MaxDreifachachlastAchsabstand1_;
		int _MaxAchsabstandDreifachAchse2_;
		int _MaxDreifachachlastAchsabstand2_;

		int _FahrzeugklassecodeAchslast_;
		int _MaxGesamtgewicht_;

		// Umsetzung
		Data data = result.getData(); // Datensatz holen
		int count = data.getArray("GesamtgewichtFahrzeugtypen").getLength();

		TlsData deApplicationData = new TlsData(20 + (3 * count));

		_MaxEinzelachlastErsteAchse_ = data.getUnscaledValue("MaxEinzelachlastErsteAchse").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxEinzelachlastErsteAchse_);

		_MaxEinzelachlast_ = data.getUnscaledValue("MaxEinzelachlast").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxEinzelachlast_);

		_MaxAchsabstandDoppelAchse1_ = data.getUnscaledValue("MaxAchsabstandDoppelAchse1").intValue();
		deApplicationData.writeIntAsByte(_MaxAchsabstandDoppelAchse1_);

		_MaxDoppelachlastAchsabstand1_ = data.getUnscaledValue("MaxDoppelachlastAchsabstand1").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxDoppelachlastAchsabstand1_);

		_MaxAchsabstandDoppelAchse2_ = data.getUnscaledValue("MaxAchsabstandDoppelAchse2").intValue();
		deApplicationData.writeIntAsByte(_MaxAchsabstandDoppelAchse2_);

		_MaxDoppelachlastAchsabstand2_ = data.getUnscaledValue("MaxDoppelachlastAchsabstand2").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxDoppelachlastAchsabstand2_);

		_MaxAchsabstandDoppelAchse3_ = data.getUnscaledValue("MaxAchsabstandDoppelAchse3").intValue();
		deApplicationData.writeIntAsByte(_MaxAchsabstandDoppelAchse3_);

		_MaxDoppelachlastAchsabstand3_ = data.getUnscaledValue("MaxDoppelachlastAchsabstand3").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxDoppelachlastAchsabstand3_);

		_MaxAchsabstandDreifachAchse1_ = data.getUnscaledValue("MaxAchsabstandDreifachAchse1").intValue();
		deApplicationData.writeIntAsByte(_MaxAchsabstandDreifachAchse1_);

		_MaxDreifachachlastAchsabstand1_ = data.getUnscaledValue("MaxDreifachachlastAchsabstand1").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxDreifachachlastAchsabstand1_);

		_MaxAchsabstandDreifachAchse2_ = data.getUnscaledValue("MaxAchsabstandDreifachAchse2").intValue();
		deApplicationData.writeIntAsByte(_MaxAchsabstandDreifachAchse2_);

		_MaxDreifachachlastAchsabstand2_ = data.getUnscaledValue("MaxDreifachachlastAchsabstand2").intValue();
		deApplicationData.writeIntAsLowHighByte(_MaxDreifachachlastAchsabstand2_);

		for (int i = 0; i < count; ++i) {
			_FahrzeugklassecodeAchslast_ = data.getArray("GesamtgewichtFahrzeugtypen").getItem(i).getUnscaledValue("FahrzeugklassecodeAchslast").intValue();
			deApplicationData.writeIntAsByte(_FahrzeugklassecodeAchslast_);
			_MaxGesamtgewicht_ = data.getArray("GesamtgewichtFahrzeugtypen").getItem(i).getUnscaledValue("MaxGesamtgewicht").intValue();
			deApplicationData.writeIntAsLowHighByte(_MaxGesamtgewicht_);
		}

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 37, 3, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * FG 2 : Typ: 38 Id: 3 Name: Parameter für Achslast- und Gewichtsklassen bei Langzeitdaten (Abruf / Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                                       Erläuterung
	 * Byte 1           Länge DE-Block                                    Länge des folgenden DE-Blocks
	 * Byte 2           Daten-Endgeräte-Kanal                             [1..254, 255]
	 * Byte 3           Typ der DE-Daten                                  [ 38 ]
	 * Byte 4           Einzelachslastklassen: Anzahl der Grenzen         [0, 1 ..12]
	 * Byte 5           Grenze der 1. Einzelachslastklasse                [ 0..65534 kg, 65535] low Byte
	 * Byte 6           Grenze der 1. Einzelachslastklasse                high Byte
	 * ..... .....
	 * Byte ...         Grenze der n-1. Einzelachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Einzelachslastklasse              high Byte
	 * Byte ...         Doppelachslastklassen: Anzahl der Grenzen         [0, 1..9]
	 * Byte ...         Grenze der 1. Doppelachslastklasse                [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der 1. Doppelachslastklasse                high Byte
	 * Byte ...         Grenze der n-1. Doppelachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Doppelachslastklasse              high Byte
	 * Byte ...         Dreifachachslastklassen: Anzahl der Grenzen       [0, 1..10]
	 * Byte ...         Grenze der 1. Dreifachachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der 1. Dreifachachslastklasse              high Byte
	 * ..... .....
	 * Byte ...         Grenze der n-1. Dreifachachslastklasse            [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Dreifachachslastklasse            high Byte
	 * Byte ...         Fahrzeugklasse 3: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 3: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Grenze der 1. GG- Klasse        high Byte
	 * ..... .....
	 * Byte ...         Fahrzeugklasse 3: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Grenze der n-1. GG- Klasse      high Byte
	 * Byte ...         Fahrzeugklasse 4: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 4: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 4: Grenze der 1. GG- Klasse        high Byte
	 * ... ...
	 * Byte ...         Fahrzeugklasse 4: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 4: Grenze der n-1. GG - Klasse     high Byte
	 * Byte ...         Fahrzeugklasse 5: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 5: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 5: Grenze der 1. GG- Klasse        high Byte
	 * ... ...
	 * Byte ...         Fahrzeugklasse 5: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 5: Grenze der n-1. GG - Klasse     high Byte
	 * </pre>
	 * Inhalt Byte: Anzahl der Klassengrenzen<br> In diesem Byte wird die Anzahl der folgenden Grenzen angegeben. Bei 0
	 * wird kein Wert für diese Fahrzeugklasse übertragen.<br> Die Klassenanzahl ist um 1 höher als die Anzahl der
	 * Grenzen.<br> <br> Inhalt Bytes: Grenzen der Klassen<br> Mit Hilfe dieser Bytes werden die Grenzen einer Klasse
	 * festgelegt. Folgende Regeln müssen dabei eingehalten werden:<br>
	 * <pre>
	 * 1. Es gilt fur alle Klassen untere Grenze &lt; Wert  obere Grenze.
	 * 2. Die Reihenfolge der Klassen im DE-Block ist immer von der kleinsten Klasse zur gro©¬ten.
	 * 3. Die unterste Grenze der ersten Klasse ist immer 0 t.
	 * 4. Die letzte Klasse ist immer nach oben unbegrenzt.
	 * 5. Die DE-Block-Struktur muss immer alle Grenzen fur eine Fahrzeugklasse enthalten, da die alten Grenzen bei
	 *    Neudefinition vollstandig geloscht werden.
	 * 6. Die neu ubermittelten Grenzen werden ab dem nachsten Messintervall angewandt. Das gerade aktuelle Intervall
	 *    wird mit den alten Grenzen zu Ende gefuhrt und ubertragen. Um Ubergangsprobleme zu vermeiden, sollten die
	 *    DE-Blocke fur Fahrzeugklassen, bei denen sich Grenzen andern, in einem Telegramm ubermittelt werden.
	 * </pre>
	 * Für Achslastklassen wird folgende Konfiguration verwendet:
	 * <pre>
	 * 10 Grenzen für Einzelachsen:   2,0 t, 4,0 t, 6,0 t, 8,0 t, 10,0 t, 11,5 t, 12,0 t, 13,0 t, 14,0 t und 15,0 t
	 * 8  Grenzen für Doppelachsen:   4,0 t, 8,0 t, 12,0 t, 16,0 t, 18,0 t, 19,0 t, 20,0 t und 22,0t
	 * 10 Grenzen für Dreifachachsen: 3,0 t, 6,0 t, 9,0 t, 12,0 t, 15,0 t, 18,0 t, 21,0 t, 24,0 t, 27,0 t und 30,0 t
	 * </pre>
	 * Für die Gesamtgewichte wird folgende Einteilung verwendet:
	 * <pre>
	 * 7 Grenzen für Fahrzeugklasse 3: 3,5 t, 7,5 t, 14,0 t, 20,0 t, 26,0 t, 32,0 t und 38,0 t
	 * 9 Grenzen für Fahrzeugklasse 4: 7,5 t, 14,0 t, 20,0 t, 26,0 t, 32,0 t, 38,0 t, 40,0t, 44,0 t und 50,0 t
	 * 5 Grenzen für Fahrzeugklasse 5: 7,5 t, 14,0 t, 20,0 t, 26,0 t und 32,0 t
	 * </pre>
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ038Id003AtgTlsAxlParameterFürAchsUndGewichtsKlassenAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		int count;
		int _GrenzWert_;

		// GrenzgewichtEinzelachslast aus Telegramm --------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtEinzelachslast").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtEinzelachslast").getUnscaledValue(i).set(_GrenzWert_);
		}

		// GrenzgewichtDoppelachslast aus Telegramm --------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtDoppelachslast").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtDoppelachslast").getUnscaledValue(i).set(_GrenzWert_);
		}

		// GrenzgewichtDreifachachslast aus Telegramm ------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtDreifachachslast").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtDreifachachslast").getUnscaledValue(i).set(_GrenzWert_);
		}

		// GrenzgewichtGesamtFahrzeugKlasse3 aus Telegramm -------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtGesamtFahrzeugKlasse3").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtGesamtFahrzeugKlasse3").getUnscaledValue(i).set(_GrenzWert_);
		}

		// GrenzgewichtGesamtFahrzeugKlasse4 aus Telegramm -------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtGesamtFahrzeugKlasse4").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtGesamtFahrzeugKlasse4").getUnscaledValue(i).set(_GrenzWert_);
		}

		// GrenzgewichtGesamtFahrzeugKlasse5 aus Telegramm -------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("GrenzgewichtGesamtFahrzeugKlasse5").setLength(count);

		for (int i = 0; i < count; ++i) {
			_GrenzWert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("GrenzgewichtGesamtFahrzeugKlasse5").getUnscaledValue(i).set(_GrenzWert_);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * FG 2 : Typ: 38 Id: 3 Name: Parameter für Achslast- und Gewichtsklassen bei Langzeitdaten (Abruf / Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                                       Erläuterung
	 * Byte 1           Länge DE-Block                                    Länge des folgenden DE-Blocks
	 * Byte 2           Daten-Endgeräte-Kanal                             [1..254, 255]
	 * Byte 3           Typ der DE-Daten                                  [ 38 ]
	 * Byte 4           Einzelachslastklassen: Anzahl der Grenzen         [0, 1 ..12]
	 * Byte 5           Grenze der 1. Einzelachslastklasse                [ 0..65534 kg, 65535] low Byte
	 * Byte 6           Grenze der 1. Einzelachslastklasse                high Byte
	 * ..... .....
	 * Byte ...         Grenze der n-1. Einzelachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Einzelachslastklasse              high Byte
	 * Byte ...         Doppelachslastklassen: Anzahl der Grenzen         [0, 1..9]
	 * Byte ...         Grenze der 1. Doppelachslastklasse                [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der 1. Doppelachslastklasse                high Byte
	 * Byte ...         Grenze der n-1. Doppelachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Doppelachslastklasse              high Byte
	 * Byte ...         Dreifachachslastklassen: Anzahl der Grenzen       [0, 1..10]
	 * Byte ...         Grenze der 1. Dreifachachslastklasse              [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der 1. Dreifachachslastklasse              high Byte
	 * ..... .....
	 * Byte ...         Grenze der n-1. Dreifachachslastklasse            [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Grenze der n-1. Dreifachachslastklasse            high Byte
	 * Byte ...         Fahrzeugklasse 3: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 3: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Grenze der 1. GG- Klasse        high Byte
	 * ..... .....
	 * Byte ...         Fahrzeugklasse 3: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Grenze der n-1. GG- Klasse      high Byte
	 * Byte ...         Fahrzeugklasse 4: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 4: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 4: Grenze der 1. GG- Klasse        high Byte
	 * ... ...
	 * Byte ...         Fahrzeugklasse 4: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 4: Grenze der n-1. GG - Klasse     high Byte
	 * Byte ...         Fahrzeugklasse 5: Anzahl der Grenzen              [0, 1..9]
	 * Byte ...         Fahrzeugklasse 5: Grenze der 1. GG- Klasse        [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 5: Grenze der 1. GG- Klasse        high Byte
	 * ... ...
	 * Byte ...         Fahrzeugklasse 5: Grenze der n-1. GG- Klasse      [ 0..65534 kg, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 5: Grenze der n-1. GG - Klasse     high Byte
	 * </pre>
	 * Inhalt Byte: Anzahl der Klassengrenzen<br> In diesem Byte wird die Anzahl der folgenden Grenzen angegeben. Bei 0
	 * wird kein Wert für diese Fahrzeugklasse übertragen.<br> Die Klassenanzahl ist um 1 höher als die Anzahl der
	 * Grenzen.<br> <br> Inhalt Bytes: Grenzen der Klassen<br> Mit Hilfe dieser Bytes werden die Grenzen einer Klasse
	 * festgelegt. Folgende Regeln müssen dabei eingehalten werden:<br>
	 * <pre>
	 * 1. Es gilt fur alle Klassen untere Grenze &lt; Wert  obere Grenze.
	 * 2. Die Reihenfolge der Klassen im DE-Block ist immer von der kleinsten Klasse zur gro©¬ten.
	 * 3. Die unterste Grenze der ersten Klasse ist immer 0 t.
	 * 4. Die letzte Klasse ist immer nach oben unbegrenzt.
	 * 5. Die DE-Block-Struktur muss immer alle Grenzen fur eine Fahrzeugklasse enthalten, da die alten Grenzen bei
	 *    Neudefinition vollstandig geloscht werden.
	 * 6. Die neu ubermittelten Grenzen werden ab dem nachsten Messintervall angewandt. Das gerade aktuelle Intervall
	 *    wird mit den alten Grenzen zu Ende gefuhrt und ubertragen. Um Ubergangsprobleme zu vermeiden, sollten die
	 *    DE-Blocke fur Fahrzeugklassen, bei denen sich Grenzen andern, in einem Telegramm ubermittelt werden.
	 * </pre>
	 * Für Achslastklassen wird folgende Konfiguration verwendet:
	 * <pre>
	 * 10 Grenzen für Einzelachsen:   2,0 t, 4,0 t, 6,0 t, 8,0 t, 10,0 t, 11,5 t, 12,0 t, 13,0 t, 14,0 t und 15,0 t
	 * 8  Grenzen für Doppelachsen:   4,0 t, 8,0 t, 12,0 t, 16,0 t, 18,0 t, 19,0 t, 20,0 t und 22,0t
	 * 10 Grenzen für Dreifachachsen: 3,0 t, 6,0 t, 9,0 t, 12,0 t, 15,0 t, 18,0 t, 21,0 t, 24,0 t, 27,0 t und 30,0 t
	 * </pre>
	 * Für die Gesamtgewichte wird folgende Einteilung verwendet:
	 * <pre>
	 * 7 Grenzen für Fahrzeugklasse 3: 3,5 t, 7,5 t, 14,0 t, 20,0 t, 26,0 t, 32,0 t und 38,0 t
	 * 9 Grenzen für Fahrzeugklasse 4: 7,5 t, 14,0 t, 20,0 t, 26,0 t, 32,0 t, 38,0 t, 40,0t, 44,0 t und 50,0 t
	 * 5 Grenzen für Fahrzeugklasse 5: 7,5 t, 14,0 t, 20,0 t, 26,0 t und 32,0 t
	 * </pre>
	 *
	 * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
	 *
	 * @return De-Block mit den konvertierten Daten.
	 */
	public DeBlock Fg002Typ038Id003AtgTlsAxlParameterFürAchsUndGewichtsKlassenAspParameterSoll(ResultData result) {
		DeBlock deBlock = null;

		// Datenblock beseht aus folgenden Inhalten:
		int _GrenzWert_;

		//Hilfvariablen
		int countGrenzgewichtEinzelachslast;
		int countGrenzgewichtDoppelachslast;
		int countGrenzgewichtDreifachachslast;
		int countGrenzgewichtGesamtFahrzeugKlasse3;
		int countGrenzgewichtGesamtFahrzeugKlasse4;
		int countGrenzgewichtGesamtFahrzeugKlasse5;

		// Umsetzung
		Data data = result.getData(); // Datensatz holen
		countGrenzgewichtEinzelachslast = data.getArray("GrenzgewichtEinzelachslast").getLength();
		countGrenzgewichtDoppelachslast = data.getArray("GrenzgewichtDoppelachslast").getLength();
		countGrenzgewichtDreifachachslast = data.getArray("GrenzgewichtDreifachachslast").getLength();
		countGrenzgewichtGesamtFahrzeugKlasse3 = data.getArray("GrenzgewichtGesamtFahrzeugKlasse3").getLength();
		countGrenzgewichtGesamtFahrzeugKlasse4 = data.getArray("GrenzgewichtGesamtFahrzeugKlasse4").getLength();
		countGrenzgewichtGesamtFahrzeugKlasse5 = data.getArray("GrenzgewichtGesamtFahrzeugKlasse5").getLength();

		int lenghtTlsData = 6 + // Anzahl der Längenbyte
		                    (countGrenzgewichtEinzelachslast * 2) + // je Grenze 2 Byte
		                    (countGrenzgewichtDoppelachslast * 2) +
		                    (countGrenzgewichtDreifachachslast * 2) +
		                    (countGrenzgewichtGesamtFahrzeugKlasse3 * 2) +
		                    (countGrenzgewichtGesamtFahrzeugKlasse4 * 2) +
		                    (countGrenzgewichtGesamtFahrzeugKlasse5 * 2);

		TlsData deApplicationData = new TlsData(lenghtTlsData);

		deApplicationData.writeIntAsByte(countGrenzgewichtEinzelachslast);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtEinzelachslast").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		deApplicationData.writeIntAsByte(countGrenzgewichtDoppelachslast);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtDoppelachslast").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		deApplicationData.writeIntAsByte(countGrenzgewichtDreifachachslast);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtDreifachachslast").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		deApplicationData.writeIntAsByte(countGrenzgewichtGesamtFahrzeugKlasse3);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtGesamtFahrzeugKlasse3").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		deApplicationData.writeIntAsByte(countGrenzgewichtGesamtFahrzeugKlasse4);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtGesamtFahrzeugKlasse4").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		deApplicationData.writeIntAsByte(countGrenzgewichtGesamtFahrzeugKlasse5);
		for (int i = 0; i < countGrenzgewichtEinzelachslast; ++i) {
			_GrenzWert_ = data.getArray("GrenzgewichtGesamtFahrzeugKlasse5").getUnscaledValue(i).intValue();
			deApplicationData.writeIntAsLowHighByte(_GrenzWert_);
		}

		// DeBlock erzeugen
		try {
			deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 38, 3, _de.getDeChannel());
		}
		catch (IllegalOsi7TelegramStructureException e) {
			debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
		}
		return deBlock;
	}

	/**
	 * Analoge Bearbeitung wie {@link #Fg002Typ060Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort},
	 * aber Daten werden als "nachgeliefert" an den DaV übergeben.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ060Id036AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg002Typ060Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 2 : Typ: 60 Id: 4 und Id: 36 Name: Einzelergebnismeldung Achslasten und Kfz-Gesamtgewicht (Version 1) (Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 60 ]
	 * Byte 4           Fahrzeugtyp                             [ Kodierung s. Anhang 2, Kapitel 3 ]
	 * Byte 5           Fahrzeuglänge                           [ 0..65534 dm, 65535 ] low Byte
	 * Byte 6           Fahrzeuglänge                           high Byte
	 * Byte 7           Geschwindigkeit                         [ 0..254 km/h, 255 ]
	 * Byte 8           Fahrzeugabstand                         [ 0..65534 dm, 65535 ] low Byte
	 * Byte 9           Fahrzeugabstand                         high Byte
	 * Byte 10          tatsächliches Gesamtgewicht             [ 0.. 65534 kg, 65535 ] low Byte
	 * Byte 11          tatsächliches Gesamtgewicht             high Byte
	 * Byte 12          Überladung                              [ siehe unten ]
	 * Byte 13          Anzahl Achslastdatengruppen             [ siehe unten ]
	 * Byte 14          1. Achse: Überlastung / Achsart         [ siehe unten ]
	 * Byte 15          1. Achse: Achslast                      [ 0..65534 kg, 65535 ] low Byte
	 * Byte 16          1. Achse: Achslast                      high Byte
	 * Byte 17          1. Achse: Achsabstand                   [ 0..65534 cm, 65535 ] low Byte
	 * Byte 18          1. Achse: Achsabstand                   high Byte
	 * .... ....
	 * Byte ...         n. Achse: Überlastung / Achsart         [ siehe unten ]
	 * Byte ...         n. Achse: Achslast                      [ 0..65534 kg, 65535 ] low Byte
	 * Byte ...         n. Achse: Achslast                      high Byte
	 * Byte ...         n. Achse: Achsabstand                   [ 0..65534 cm, 65535 ] low Byte
	 * Byte ...         n. Achse: Achsabstand                   high Byte
	 * </pre>
	 * Inhalt Byte: Fahrzeugtyp<br> In diesem Byte wird nach Anhang 2, Kapitel 3 codiert der ermittelte Fahrzeugtyp
	 * gespeichert:<br> <br> Inhalt Byte: Fahrzeugabstand<br> In diesem Byte wird der Abstand zwischen dem Ende des
	 * vorherfahrenden Fahrzeugs und dem Beginn dieses Fahrzeugs abgespeichert. Als Abstand wird das Produkt aus der
	 * gemessener Nettozeitlücke zum vorausfahrenden Fahrzeug und Geschwindigkeit des aktuellen Fahrzeugs gespeichert. Bei
	 * dem ersten Messwert wird der Wert 65535 (Wert nicht ermittelbar) eingetragen.<br> <br> Inhalt Byte: Überladung<br>
	 * Mit diesem Byte wird eine Überschreitung des zulässigen Gesamtgewichts gekennzeichnet:
	 * <pre>
	 * Bit 0 = 0: keine Überladung
	 * 1:         Überladung
	 * </pre>
	 * Inhalt Byte: Anzahl Achslastdaten<br> Diese Byte gibt die Anzahl der nachfolgenden Datengruppen, in denen jeweils
	 * die Daten für die einzelnen Achsen des Fahrzeugs übertragen werden, an. Eine Datengruppe besteht jeweils aus den
	 * Bytes Überlastung/Achsart, Achslast und Achsabstand. Bei Fahrzeugtyp 1 (Pkw) werden die einzelnen Achslasten nicht
	 * übertragen; das Byte wird in diesem Fall gleich 0 gesetzt.<br> <br> Inhalt Byte: Überlastung/Achsart<br> Mit diesem
	 * Byte wird eine Überschreitung der zulässigen Achslast und die Achsart gekennzeichnet:
	 * <pre>
	 * Bit 0..4:   1:   Einzelachse
	 *             2:   Doppelachse
	 *             3:   Dreifachachse
	 * Bit 5..6 =  0    (frei für spätere Definitionen)
	 * Bit 7 =     0:   keine Überschreitung
	 *             1:   Überschreitung
	 * </pre>
	 * Inhalt Bytes: Achslast<br> Die Bytes enthalten die ermittelte Achslast einer einzelnen Achse. Bei Mehrfachachsen
	 * wird für jede einzelne Achse ein gesonderter Satz Messwerte (jeweils Überladung/Achsart, Achslast, Achsabstand) im
	 * DE-Block übertragen. Als Achsart wird bei den einzelnen Messwerten jeweils der Typ der Mehrfachachse (nicht
	 * Einzelachse!) angegeben.<br> <br> Inhalt Byte: Achsabstand<br> In diesem Byte wird der gemessene Abstand zwischen
	 * der vorherfahrenden Achse und der jetzigen Achse abgespeichert. Bei der ersten Achse eines Fahrzeugs wird der
	 * Abstand zur letzten Achse der vorherfahrenden Fahrzeugs angebeben. Bei der ersten Achse des ersten Fahrzeug wird der
	 * Wert 65535 eingetragen.<br> 	 * @param deBlock Der zu bearbeitende De-Block.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ060Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
		data.getTimeValue("T").setSeconds(_eakConversionModul.getAxlIntervalDuration());

		// Fahrzeugtyp aus Telegramm -----------------------------------------------------------------------------------
		int _FzTyp_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_FzTyp_) {
			case 1:
			case 2:
			case 3:
			case 4:
			case 5:
			case 6:
			case 8:
			case 9:
			case 10:
			case 11:
			case 12:
			case 32:
			case 33:
			case 34:
			case 35:
			case 36:
			case 37:
			case 40:
			case 41:
			case 42:
			case 43:
			case 44:
			case 45:
			case 48:
			case 49:
			case 50:
			case 51:
			case 52:
			case 53:
			case 56:
			case 57:
			case 58:
			case 59:
			case 60:
			case 61:
			case 64:
			case 65:
			case 66:
			case 67:
			case 68:
			case 69:
			case 96:
			case 97:
			case 98:
			case 99:
			case 104:
			case 105:
			case 106:
			case 107:
			case 120:
			case 121:
			case 122:
			case 123:
			case 124:
			case 125:
				data.getUnscaledValue("FzTyp").set(_FzTyp_);
				break;

			default:
				debug.warning("FahrzeugtypAchslast-Wert ungültig : " + _FzTyp_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Fahrzeuglänge aus Telegramm ---------------------------------------------------------------------------------
		int _FzLänge_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzLänge").set(_FzLänge_);

		// Geschwindigkeit aus Telegramm -------------------------------------------------------------------------------
		int _vFz_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("vFz").set(_vFz_);

		// Fahrzeugabstand aus Telegramm -------------------------------------------------------------------------------
		int _FzAbstand_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzAbstand").set(_FzAbstand_);

		// Fahrzeuggesamtgewicht aus Telegramm -------------------------------------------------------------------------
		int _FzGesamtGewicht_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzGesamtGewicht").set(_FzGesamtGewicht_);

		// Fahrzeugüberladung aus Telegramm -------------------------------------------------------------------------
		int _FzÜberladung_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_FzTyp_) {
			case 0:
			case 1:
				data.getUnscaledValue("FzÜberladung").set(_FzÜberladung_);
				break;

			default:
				debug.warning("FzÜberladung-Wert ungültig : " + _FzÜberladung_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Achlastdatengruppen aus Telegramm ---------------------------------------------------------------------------
		int _Wert_;
		int _Überlastung_;
		int count = deBlock.getDeData().readUnsignedByteAsInt();

		data.getArray("ÜberlastungAchse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
			_Überlastung_ = (_Wert_ & 0x80) >>> 7; // Überlastung im oberen Bit kodiert
			switch (_Wert_ & 0x1f) {
				case 1:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastEinzelachse").set(_Überlastung_);
					break;
				case 2:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastDoppelachse").set(_Überlastung_);
					break;
				case 3:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastDreifachachse").set(_Überlastung_);
					break;
				default:
					debug.warning("Überlastung/Achsart-Wert ungültig : " + _Wert_ + Debug.NEWLINE +
					              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
					              deBlock.toString());
					return resultData;
			}

			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("Achslast").set(_Wert_);
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("Achsabstand").set(_Wert_);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * Analoge Bearbeitung wie {@link #Fg002Typ061Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort},
	 * aber Daten werden als "nachgeliefert" an den DaV übergeben.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ061Id036AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg002Typ061Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 2 : Typ: 61 Id: 4 und Id: 36 Name: Einzelergebnismeldung Radlasten und Kfz-Gesamtgewicht (Version 2) (Antwort).
	 * TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                             Erläuterung
	 * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks
	 * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                        [ 61 ]
	 * Byte 4           Fahrzeugtyp                             [ Kodierung s. Anhang 2, Kapitel 3 ]
	 * Byte 5           Fahrzeuglänge                           [ 0..65534 dm, 65535 ] low Byte
	 * Byte 6           Fahrzeuglänge                           high Byte
	 * Byte 7           Geschwindigkeit                         [ 0..254 km/h, 255 ]
	 * Byte 8           Fahrzeugabstand                         [ 0..65534 dm, 65535 ] low Byte
	 * Byte 9           Fahrzeugabstand                         high Byte
	 * Byte 10          tatsächliches Gesamtgewicht             [ 0.. 65534 kg, 65535 ] low Byte
	 * Byte 11          tatsächliches Gesamtgewicht             high Byte
	 * Byte 12          Überladung                              [ siehe unten ]
	 * Byte 13          Anzahl Achslastdatengruppen             [ siehe unten ]
	 * Byte 14          1. Achse: Überlastung / Achsart         [ siehe unten ]
	 * Byte 15          1. Achse: Radlast des linken Rads       [ 0..25,4 t, 255 ]
	 * Byte 16          1. Achse: Radlast des rechten Rads      [ 0..25,4 t, 255 ]
	 * Byte 17          1. Achse: Achsabstand                   [ 0..65534 cm, 65535 ] low Byte
	 * Byte 18          1. Achse: Achsabstand                   high Byte
	 * .... ....
	 * Byte ...         n. Achse: Überlastung / Achsart         [ siehe unten ]
	 * Byte ...         n. Achse: Radlast des linken Rads       [ 0..25,4 t, 255 ]
	 * Byte ...         n. Achse: Radlast des rechten Rads      [ 0..25,4 t, 255 ]
	 * Byte ...         n. Achse: Achsabstand                   [ 0..65534 cm, 65535 ] low Byte
	 * Byte ...         n. Achse: Achsabstand high Byte
	 * </pre>
	 * Inhalt Byte: Fahrzeugtyp<br> In diesem Byte wird nach Anhang 2, Kapitel 3 codiert der ermittelte Fahrzeugtyp
	 * gespeichert:<br> <br> Inhalt Byte: Fahrzeugabstand<br> In diesem Byte wird der Abstand zwischen dem Ende des
	 * vorherfahrenden Fahrzeugs und dem Beginn dieses Fahrzeugs abgespeichert. Als Abstand wird das Produkt aus der
	 * gemessener Nettozeitlücke zum vorausfahrenden Fahrzeug und Geschwindigkeit des aktuellen Fahrzeugs gespeichert. Bei
	 * dem ersten Messwert wird der Wert 65535 (Wert nicht ermittelbar) eingetragen.<br> <br> Inhalt Byte: Überladung<br>
	 * Mit diesem Byte wird eine Überschreitung des zulässigen Gesamtgewichts gekennzeichnet:
	 * <pre>
	 * Bit 0 =    0: keine Überladung
	 *            1: Überladung
	 * </pre>
	 * Inhalt Byte: Anzahl Achslastdaten<br> Diese Byte gibt die Anzahl der nachfolgenden Datengruppen, in denen jeweils
	 * die Daten für die einzelnen Achsen des Fahrzeugs übertragen werden, an. Eine Datengruppe besteht jeweils aus den
	 * Bytes Überlastung/Achsart, Achslast und Achsabstand. Bei Fahrzeugtyp 1 (Pkw) werden die einzelnen Achslasten nicht
	 * übertragen; das Byte wird in diesem Fall gleich 0 gesetzt.<br> <br> Inhalt Byte: Überlastung/Achsart<br> Mit diesem
	 * Byte wird eine Überschreitung der zulässigen Achslast und die Achsart gekennzeichnet:
	 * <pre>
	 * Bit 0..4:   1:    Einzelachse
	 *             2:    Doppelachse
	 *             3:    Dreifachachse
	 * Bit 5..6 =  0     (frei für spätere Definitionen)
	 * Bit 7 =     0:    keine Überschreitung
	 *             1:    Überschreitung
	 * </pre>
	 * Inhalt Bytes: Radlast<br> Die Bytes enthalten die ermittelte linke/ rechte Radlast einer einzelnen Achse, gesehen in
	 * Fahrtrichtung. Als Radlast gilt dabei die Last aller Räder (auch bei Doppelreifen) einer Achsenseite. Bei
	 * Mehrfachachsen wird für jede einzelne Achse ein gesonderter Satz Messwerte (jeweils Überladung/Achsart, Radasten,
	 * Achsabstand) im DE-Block übertragen. Als Achsart wird bei den einzelnen Messwerten jeweils der Typ der Mehrfachachse
	 * (nicht Einzelachse!) angegeben.<br> <br> Inhalt Byte: Achsabstand<br> In diesem Byte wird der gemessene Abstand
	 * zwischen der vorherfahrenden Achse und der jetzigen Achse abgespeichert. Bei der ersten Achse eines Fahrzeugs wird
	 * der Abstand zur letzten Achse der vorherfahrenden Fahrzeugs angebeben. Bei der ersten Achse des ersten Fahrzeug wird
	 * der Wert 65535 eingetragen.<br>	 * @param deBlock Der zu bearbeitende De-Block.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ061Id004AtgTlsAxlEinzelErgebnisMeldungAchsLastenUndKfzGesamtGewichteVersion1Bis2AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		// Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
		data.getTimeValue("T").setSeconds(_eakConversionModul.getAxlIntervalDuration());

		// Fahrzeugtyp aus Telegramm -----------------------------------------------------------------------------------
		int _FzTyp_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_FzTyp_) {
			case 1:
			case 2:
			case 3:
			case 4:
			case 5:
			case 6:
			case 8:
			case 9:
			case 10:
			case 11:
			case 12:
			case 32:
			case 33:
			case 34:
			case 35:
			case 36:
			case 37:
			case 40:
			case 41:
			case 42:
			case 43:
			case 44:
			case 45:
			case 48:
			case 49:
			case 50:
			case 51:
			case 52:
			case 53:
			case 56:
			case 57:
			case 58:
			case 59:
			case 60:
			case 61:
			case 64:
			case 65:
			case 66:
			case 67:
			case 68:
			case 69:
			case 96:
			case 97:
			case 98:
			case 99:
			case 104:
			case 105:
			case 106:
			case 107:
			case 120:
			case 121:
			case 122:
			case 123:
			case 124:
			case 125:
				data.getUnscaledValue("FzTyp").set(_FzTyp_);
				break;

			default:
				debug.warning("FahrzeugtypAchslast-Wert ungültig : " + _FzTyp_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Fahrzeuglänge aus Telegramm ---------------------------------------------------------------------------------
		int _FzLänge_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzLänge").set(_FzLänge_);

		// Geschwindigkeit aus Telegramm -------------------------------------------------------------------------------
		int _vFz_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("vFz").set(_vFz_);

		// Fahrzeugabstand aus Telegramm -------------------------------------------------------------------------------
		int _FzAbstand_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzAbstand").set(_FzAbstand_);

		// Fahrzeuggesamtgewicht aus Telegramm -------------------------------------------------------------------------
		int _FzGesamtGewicht_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
		data.getUnscaledValue("FzGesamtGewicht").set(_FzGesamtGewicht_);

		// Fahrzeugüberladung aus Telegramm -------------------------------------------------------------------------
		int _FzÜberladung_ = deBlock.getDeData().readUnsignedByteAsInt();
		switch (_FzTyp_) {
			case 0:
			case 1:
				data.getUnscaledValue("FzÜberladung").set(_FzÜberladung_);
				break;

			default:
				debug.warning("FzÜberladung-Wert ungültig : " + _FzÜberladung_ + Debug.NEWLINE +
				              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
				              deBlock.toString());
				return resultData;
		}

		// Achlastdatengruppen aus Telegramm ---------------------------------------------------------------------------
		int _Wert_;
		int _Überlastung_;
		int count = deBlock.getDeData().readUnsignedByteAsInt();

		data.getArray("ÜberlastungAchse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
			_Überlastung_ = (_Wert_ & 0x80) >>> 7; // Überlastung im oberen Bit kodiert
			switch (_Wert_ & 0x1f) {
				case 1:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastEinzelachse").set(_Überlastung_);
					break;
				case 2:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastDoppelachse").set(_Überlastung_);
					break;
				case 3:
					data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("ÜberlastDreifachachse").set(_Überlastung_);
					break;
				default:
					debug.warning("Überlastung/Achsart-Wert ungültig : " + _Wert_ + Debug.NEWLINE +
					              "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE +
					              deBlock.toString());
					return resultData;
			}

			_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
			data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("RadlastLinks").set(_Wert_);
			_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
			data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("RadlastRechts").set(_Wert_);
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("ÜberlastungAchse").getItem(i).getUnscaledValue("Achsabstand").set(_Wert_);
		}
		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}

	/**
	 * Analoge Bearbeitung wie {@link #Fg002Typ065Id004AtgTlsAxlErgebnisMeldungAchsLastDatenVersion10AspTlsAntwort}, aber
	 * Daten werden als "nachgeliefert" an den DaV übergeben.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ065Id036AtgTlsAxlErgebnisMeldungAchsLastDatenVersion10AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg002Typ065Id004AtgTlsAxlErgebnisMeldungAchsLastDatenVersion10AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * FG 2 : Typ: 65 Id: 4 und Id: 36 Name: Ergebnismeldung Achslastdaten Version 10 (Antwort). TLS-Datenbeschreibung:
	 * <pre>
	 * Position         Bezeichnung                                    Erläuterung
	 * Byte 1           Länge DE-Block                                 Länge des folgenden DE-Blocks
	 * Byte 2           Daten-Endgeräte-Kanal                          [ 1..254 ]
	 * Byte 3           Typ der DE-Daten                               [ 65 ]
	 * Byte 4           Anzahl Einzelachslastklassen:                  [0, 2 ..13]
	 * Byte 5           Einzelachslastklasse 1                         [ 0..65534, 65535] low Byte
	 * Byte 6           Einzelachslastklasse 1                         high Byte
	 * ..... .....
	 * Byte ...         Einzelachslastklasse N                         [ 0..65534, 65535] low Byte
	 * Byte ...         Einzelachslastklasse N                         high Byte
	 * Byte ...         Anzahl Doppelachslastklassen                   [0, 2 ..10]
	 * Byte ...         Doppelachslastklasse 1                         [ 0..65534, 65535] low Byte
	 * Byte ...         Doppelachslastklasse 1                         high Byte
	 * ..... .....
	 * Byte ...         Doppelachslastklasse N                         [ 0..65534, 65535] low Byte
	 * Byte ...         Doppelachslastklasse N                         high Byte
	 * Byte ...         Anzahl Dreifachachslastklassen                 [0, 2 ..11]
	 * Byte ...         Dreifachachslastklasse 1                       [ 0..65534, 65535] low Byte
	 * Byte ...         Dreifachachslastklasse 1                       high Byte
	 * ..... .....
	 * Byte ...         Dreifachachslastklasse N                       [ 0..65534, 65535] low Byte
	 * Byte ...         Dreifachachslastklasse N                       high Byte
	 * Byte ...         Fahrzeugklasse 3: Anzahl Überladungen          [ 0..254 Kfz, 255]
	 * Byte ...         Fahrzeugklasse 4: Anzahl Überladungen          [ 0..254 Kfz, 255]
	 * Byte ...         Fahrzeugklasse 5: Anzahl Überladungen          [ 0..254 Kfz, 255]
	 * Byte ...         Fahrzeugklasse 3:Anzahl Gesamtgewichtsklassen  [0, 2..10]
	 * Byte ...         Fahrzeugklasse 3: Gesamtgewichtsklasse 1       [ 0..65534, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Gesamtgewichtsklasse 1       high Byte
	 * ..... .....
	 * Byte ...         Fahrzeugklasse 3: Gesamtgewichtsklasse N       [ 0..65534, 65535] low Byte
	 * Byte ...         Fahrzeugklasse 3: Gesamtgewichtsklasse N       high Byte
	 * Byte ...         Fahrzeugklasse 4: Anzahl Gesamtgewichtsklassen [0, 2..10]
	 * ... ...
	 * Byte ...         Fahrzeugklasse 4: Gesamtgewichtsklasse N       high Byte
	 * Byte ...         Fahrzeugklasse 5: Anzahl Gesamtgewichtsklassen [0, 2..10]
	 * ... ...
	 * Byte ...         Fahrzeugklasse 5: Gesamtgewichtsklasse N       high Byte
	 * </pre>
	 * Inhalt Bytes: Anzahl Einzelachslastklassen, Doppelachslastklassen und Dreifachachslasten<br> Der Inhalt dieses Bytes
	 * gibt die Anzahl der folgenden Achslastklassen und nicht die Anzahl der Bytes an. Bei 0 folgen für die entsprechende
	 * Achsart keine Achslastklassen.<br> <br> Inhalt Bytes: Achslastklassen<br> Für jede Klasse wird die Anzahl der Achsen
	 * aller Fahrzeuge pro Zeitintervall als vorzeichenloser Wert im Bereich von 0 bis maximal 65534 übertragen. Dabei
	 * werden auch die einzelnen Achsen von Mehrfachachsen mit entsprechender Anzahl Einzelwerte erfasst.<br> <br> Inhalt
	 * Bytes: Doppel-/Dreifachachslastklassen<br> Für jede Klasse wird die Anzahl entsprechender Achsen aller Fahrzeuge pro
	 * Zeitintervall als vorzeichenloser Wert im Bereich von 0 bis maximal 65534 übertragen. Dabei wird das summierte
	 * Gewicht aller Achsen der Mehrfachachse erfasst.<br> <br> Inhalt Bytes: Anzahl Überladungen<br> Es wird die Anzahl
	 * der Fahrzeuge, bei der eine Überschreitungen des zulässigen Gesamtgewichts oder der höchstzulässigen Achslast
	 * ermittelt wurde, in diesen Bytes je Fahrzeugklasse übermittelt. Übersteigt die Anzahl den Wert 253, wird 254
	 * übertragen.<br>	 * @param deBlock Der zu bearbeitende De-Block.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg002Typ065Id004AtgTlsAxlErgebnisMeldungAchsLastDatenVersion10AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		ResultData resultData = null;

		int count;
		int _Wert_;

		// Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
		data.getTimeValue("T").setSeconds(_eakConversionModul.getAxlIntervalDuration());

		// AnzEinzelachslastKlasse aus Telegramm -----------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzEinzelachslastKlasse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzEinzelachslastKlasse").getUnscaledValue(i).set(_Wert_);
		}

		// AnzDoppelachslastKlasse aus Telegramm -----------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzDoppelachslastKlasse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzDoppelachslastKlasse").getUnscaledValue(i).set(_Wert_);
		}

		// AnzDreifachachslastKlasse aus Telegramm ---------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzDreifachachslastKlasse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzDreifachachslastKlasse").getUnscaledValue(i).set(_Wert_);
		}

		// AnzÜberladungLkw aus Telegramm ------------------------------------------------------------------------------
		_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("AnzÜberladungLkw").set(_Wert_);

		// AnzÜberladungLkwA aus Telegramm -----------------------------------------------------------------------------
		_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("AnzÜberladungLkwA").set(_Wert_);

		// AnzÜberladungBusse aus Telegramm ----------------------------------------------------------------------------
		_Wert_ = deBlock.getDeData().readUnsignedByteAsInt();
		data.getUnscaledValue("AnzÜberladungBusse").set(_Wert_);

		// AnzGewichtsKlasseLkw aus Telegramm --------------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzGewichtsKlasseLkw").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzGewichtsKlasseLkw").getUnscaledValue(i).set(_Wert_);
		}

		// AnzGewichtsKlasseLkwA aus Telegramm -------------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzGewichtsKlasseLkwA").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzGewichtsKlasseLkwA").getUnscaledValue(i).set(_Wert_);
		}

		// AnzGewichtsKlasseBusse aus Telegramm ------------------------------------------------------------------------
		count = deBlock.getDeData().readUnsignedByteAsInt();
		data.getArray("AnzGewichtsKlasseBusse").setLength(count);

		for (int i = 0; i < count; ++i) {
			_Wert_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
			data.getArray("AnzGewichtsKlasseBusse").getUnscaledValue(i).set(_Wert_);
		}

		//Ergebnisdatensatz erzeugen...
		resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);
		return resultData;
	}
}
